import type { AxiosInstance, AxiosRequestConfig } from "axios";
import { type QueryClient, type UseMutationOptions, type UseQueryOptions, type UseMutationResult, type UseQueryResult } from "react-query";
export declare type Assessment = {
    id?: string;
    name?: string;
    description?: string;
    questions?: AssessmentQuestion[];
};
export declare type AssessmentAnswer = {
    persistent?: boolean;
    id?: string;
    answer?: string;
    correctAnswer?: boolean;
};
export declare type AssessmentAnswerResponse = {
    id?: string;
    student?: Student;
    marked?: boolean;
    student_response?: string;
};
export declare type AssessmentQuestion = {
    id?: string;
    question?: string;
    explanation?: string;
    mark?: number;
    answers?: AssessmentAnswer[];
    is_long_form?: boolean;
};
export declare type AssessmentReports = {
    id?: string;
    student?: Student;
    status?: MarkingStatusEnum;
    total_marks?: number;
    percentage?: number;
    totalMarkQuestions?: number;
    responses?: AssessmentAnswerResponse[];
};
export declare type AssessmentStatus = {
    id?: string;
    completeStatus?: CompleteStatus;
    started_at?: string;
    completed_at?: string;
    student?: Student;
};
export declare type Classroom = {
    id?: string;
    name?: string;
    description?: string;
    subjects?: Subject[];
    level_grade?: Grade;
    teacher?: Teacher;
};
export declare type ClassroomSubscription = {
    id?: string;
    classroom?: Classroom;
    subscription?: UserSubscription;
};
export declare type CompleteStatus = "DOING" | "DONE";
export declare type CreateAssessmentAnswer = {
    question?: UUID;
    answer?: string;
    correct_answer?: boolean;
};
export declare type CreateAssessmentAnswerResponse = {
    answer?: UUID;
    report?: UUID;
    student_response?: string;
};
export declare type CreateAssessmentConsumable = {
    name?: string;
    description?: string;
    subject?: UUID;
};
export declare type CreateAssessmentGrading = {
    assessment?: UUID;
};
export declare type CreateAssessmentLongAnswerResponse = {
    question?: UUID;
    report?: UUID;
    student_response?: string;
};
export declare type CreateAssessmentQuestion = {
    assessment?: UUID;
    question?: string;
    explanation?: string;
    mark?: number;
    is_long_form?: boolean;
};
export declare type CreateAssessmentStatus = {
    assessment?: UUID;
};
export declare type CreateClassroomConsumable = {
    name?: string;
    description?: string;
    level_grade?: Grade;
};
export declare type CreateClassroomSub = {
    user_sub?: UUID;
    classroom?: UUID;
};
export declare type CreateDocument = {
    name?: string;
    description?: string;
    file?: UUID;
    lesson?: UUID;
};
export declare type CreateExerciseAnswer = {
    question?: UUID;
    answer?: string;
    correct_answer?: boolean;
};
export declare type CreateExerciseAnswerResponse = {
    answer?: UUID;
    report?: UUID;
};
export declare type CreateExerciseConsumable = {
    name?: string;
    description?: string;
    lesson?: UUID;
};
export declare type CreateExerciseGrading = {
    exercise?: UUID;
};
export declare type CreateExerciseQuestion = {
    exercise?: UUID;
    question?: string;
    explanation?: string;
    mark?: number;
};
export declare type CreateExerciseStatus = {
    exercise?: UUID;
};
export declare type CreateFileConsumable = {
    name?: string;
    description?: string;
};
export declare type CreateFileResponse = {
    path?: URL;
    file?: string;
};
export declare type CreateLessonConsumable = {
    name?: string;
    description?: string;
    topic?: UUID;
};
export declare type CreateMedia = {
    name?: string;
    description?: string;
    file?: UUID;
    playlist?: UUID;
};
export declare type CreateNotesConsumable = {
    name?: string;
    description?: string;
    content?: string;
    lesson?: UUID;
};
export declare type CreatePlanGroup = {
    name?: string;
    description?: string;
    created_at?: string;
};
export declare type CreatePlaylistConsumable = {
    name?: string;
    description?: string;
    lesson?: UUID;
    type?: PlaylistMediaEnum;
};
export declare type CreateSubjects = {
    name?: SubjectsEnum;
    description?: string;
    level?: Grade;
    category?: SubjectsCatergoryEnum;
    classroom?: UUID;
};
export declare type CreateSubscription = {
    name?: string;
    description?: string;
    cost?: number;
    group?: UUID;
    recurrence_unit?: RecurrenceUnit;
    frequency?: number;
};
export declare type CreateTopicConsumable = {
    name?: string;
    description?: string;
    subject?: UUID;
};
export declare type CreateTransaction = {
    subscription?: UUID;
    transaction_date?: string;
};
export declare type CreateUser = {
    username?: string;
    password?: string;
    phoneNumber?: string;
    birthdate?: string;
    firstName?: string;
    lastName?: string;
    roles?: UserRoles[];
};
export declare type CreateUserSub = {
    name?: string;
    description?: string;
    subscription?: UUID;
    date_billing_start?: string;
};
export declare type Customer = {
    last_name?: string;
    first_name?: string;
    customer_code?: string;
    email?: string;
};
export declare type Data = {
    created_at?: string;
    paid_at?: string;
    ip_address?: string;
    customer?: Customer;
};
export declare type DeletePayload = {
    id?: UUID;
};
export declare type Document = {
    id?: string;
    file?: File;
};
export declare type EventData = {
    event?: string;
    data?: Data;
};
export declare type Exercise = {
    id?: string;
    name?: string;
    description?: string;
    questions?: ExerciseQuestion[];
};
export declare type ExerciseAnswer = {
    id?: string;
    answer?: string;
    correct_answer?: boolean;
};
export declare type ExerciseAnswerResponse = {
    id?: string;
    student?: Student;
    marked?: boolean;
    student_response?: string;
    answer?: ExerciseAnswer;
};
export declare type ExerciseQuestion = {
    id?: string;
    question?: string;
    explanation?: string;
    mark?: number;
    answers?: ExerciseAnswer[];
};
export declare type ExerciseReports = {
    id?: string;
    student?: Student;
    status?: MarkingStatusEnum;
    total_marks?: number;
    percentage?: number;
    totalMarkQuestions?: number;
    responses?: ExerciseAnswerResponse[];
};
export declare type ExerciseStatus = {
    id?: string;
    completeStatus?: CompleteStatus;
    started_at?: string;
    completed_at?: string;
};
export declare type File = {
    id?: string;
    name?: string;
    description?: string;
    created_at?: string;
    status?: FileCompleteEnum;
    path?: string;
};
export declare type FileCompleteEnum = "INCOMPLETE" | "COMPLETE";
export declare type Grade = "GRADE_ONE" | "GRADE_TWO" | "GRADE_THREE" | "GRADE_FOUR" | "GRADE_FIVE" | "GRADE_SIX" | "GRADE_SEVEN" | "FORM_ONE" | "FORM_TWO" | "FORM_THREE" | "FORM_FOUR" | "FORM_FIVE" | "FORM_SIX";
export declare type Lesson = {
    id?: string;
    name?: string;
    description?: string;
    topic?: Topic;
};
export declare type LoginUser = {
    username?: string;
    password?: string;
};
export declare type MarkAssessment = {
    report?: UUID;
};
export declare type MarkExercise = {
    report?: UUID;
};
export declare type MarkLongAssessmentAnswer = {
    report?: UUID;
    response?: UUID;
    mark?: number;
};
export declare type MarkingStatusEnum = "COMPLETE" | "MARKING" | "STARTED";
export declare type Media = {
    id?: string;
    file?: File;
    media_type?: PlaylistMediaEnum;
};
export declare type Notes = {
    id?: string;
    name?: string;
    description?: string;
    content?: string;
};
export declare type PlanCost = {
    id?: string;
    plan?: SubscriptionPlan;
    recurrence_period?: number;
    recurrence_unit?: RecurrenceUnit;
    cost?: number;
};
export declare type PlanEnum = "free" | "premium";
export declare type PlanGroup = {
    id?: string;
    name?: string;
    description?: string;
    status?: PlanGroupStatus;
    created_at?: string;
    plans?: PlanCost[];
};
export declare type PlanGroupStatus = "ACTIVE" | "INACTIVE";
export declare type Playlist = {
    id?: string;
    name?: string;
    lesson?: Lesson;
    type?: PlaylistMediaEnum;
};
export declare type PlaylistMediaEnum = "video" | "audio";
export declare type RecurrenceUnit = "MONTH" | "YEAR";
export declare type Role = {
    id?: string;
    runhareUser?: RunhareUser;
    role?: string;
};
export declare type RunhareUser = {
    id?: string;
    username: string;
    birthdate?: string;
    email?: string;
    phoneNumber?: string;
    firstName?: string;
    lastName?: string;
    roles?: Role[];
};
export declare type StatsData = {
    users?: number;
};
export declare type Student = {
    id?: string;
    username?: string;
    level?: Grade;
};
export declare type StudentData = {
    level?: Grade;
};
export declare type Subject = {
    id?: string;
    name?: SubjectsEnum;
    description?: string;
    plan?: PlanEnum;
    level?: Grade;
    classroom?: Classroom;
    topics?: Topic[];
    category?: SubjectsCatergoryEnum;
    teacher?: Teacher;
};
export declare type SubjectsCatergoryEnum = "Arts" | "Sciences" | "Commercials";
export declare type SubjectsEnum = "Mathematics" | "Business_Studies" | "Combined_Science" | "Physics" | "Chemistry" | "Computer_Science" | "English" | "Geography" | "Accounting" | "Economics" | "Biology" | "Commerce";
export declare type SubscriptionPlan = {
    id?: string;
    name?: string;
    description?: string;
    grace_period?: number;
};
export declare type SubscriptionTransaction = {
    id?: string;
    user?: RunhareUser;
    subscription?: PlanCost;
    date_transaction?: string;
    amount?: number;
};
export declare type Task = {
    id?: string;
    created_at?: string;
};
export declare type Teacher = {
    id?: string;
    username?: string;
    classrooms?: Classroom[];
    subjects?: Subject[];
};
export declare type TokenResponse = {
    token?: string;
};
export declare type Topic = {
    id?: string;
    name?: string;
    description?: string;
    subject?: Subject;
};
export declare type URL = {
    protocol?: string;
    host?: string;
    port?: number;
    file?: string;
    authority?: string;
    ref?: string;
    hashCode?: number;
    defaultPort?: number;
    content?: {};
    serializedHashCode?: number;
};
export declare type UUID = string;
export declare type UserRoles = "admin" | "teacher" | "student";
export declare type UserSubscription = {
    id?: string;
    subscription?: PlanCost;
    date_billing_start?: string;
    date_billing_end?: string;
    date_billing_last?: string;
    date_billing_next?: string;
    active?: boolean;
    cancelled?: boolean;
};
export declare type AxiosConfig = {
    paramsSerializer?: AxiosRequestConfig["paramsSerializer"];
};
export declare type Config = {
    mutations?: MutationConfigs;
    axios?: AxiosConfig;
};
export declare function initialize(axios: AxiosInstance, config?: Config): {
    requests: {
        readonly assessmentResourceDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly assessmentResourceCreate: (payload: CreateAssessmentConsumable) => Promise<Assessment>;
        readonly assessmentAnswerResourceCreate: (payload: CreateAssessmentAnswer) => Promise<AssessmentAnswer>;
        readonly assessmentAnswerResourceDelete: (id: string) => Promise<{}>;
        readonly assessmentAnswerResourceUpdate: (payload: CreateAssessmentAnswer, id: string) => Promise<AssessmentAnswer>;
        readonly assessmentAnswerResourceList: (q: string) => Promise<AssessmentAnswer[]>;
        readonly assessmentResourceComplete: (payload: CreateAssessmentStatus) => Promise<AssessmentStatus>;
        readonly assessmentQuestionResourceCreate: (payload: CreateAssessmentQuestion) => Promise<AssessmentQuestion>;
        readonly assessmentQuestionResourceList: (assessment_id: string) => Promise<AssessmentQuestion[]>;
        readonly assessmentQuestionResourceDelete: (id: string) => Promise<{}>;
        readonly assessmentQuestionResourceUpdate: (payload: CreateAssessmentQuestion, id: string) => Promise<AssessmentQuestion>;
        readonly assessmentResourceList: (subject_id: string) => Promise<Assessment[]>;
        readonly assessmentResourceStart: (payload: CreateAssessmentStatus) => Promise<AssessmentStatus>;
        readonly assessmentResourceGet: (id: string) => Promise<Assessment>;
        readonly assessmentResourceUpdate: (payload: CreateAssessmentConsumable, id: string) => Promise<Assessment>;
        readonly authenticationResourceLogin: (payload: LoginUser) => Promise<TokenResponse>;
        readonly authenticationResourceRegister: (payload: CreateUser) => Promise<TokenResponse>;
        readonly classroomResourceDelete: (payload: DeletePayload) => Promise<{}>;
        readonly classroomResourceCreate: (payload: CreateClassroomConsumable) => Promise<Classroom>;
        readonly classroomResourceGetByStudentLevel: () => Promise<Classroom[]>;
        readonly classroomResourceGetTeacherId: () => Promise<Classroom[]>;
        readonly classroomResourceGet: (id: string) => Promise<Classroom>;
        readonly classroomResourceUpdate: (payload: CreateClassroomConsumable, id: string) => Promise<Classroom>;
        readonly documentResourceCreate: (payload: CreateDocument) => Promise<Document>;
        readonly documentResourceGetByLesson: (id: string) => Promise<Document[]>;
        readonly documentResourceGet: (id: string) => Promise<Document>;
        readonly exerciseResourceDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly exerciseResourceCreate: (payload: CreateExerciseConsumable) => Promise<Exercise>;
        readonly exerciseAnswerResourceCreate: (payload: CreateExerciseAnswer) => Promise<ExerciseAnswer>;
        readonly exerciseAnswerResourceDelete: (id: string) => Promise<{}>;
        readonly exerciseAnswerResourceUpdate: (payload: CreateExerciseAnswer, id: string) => Promise<ExerciseAnswer>;
        readonly exerciseAnswerResourceList: (q: string) => Promise<ExerciseAnswer[]>;
        readonly exerciseResourceComplete: (payload: CreateExerciseStatus) => Promise<ExerciseStatus>;
        readonly exerciseResourceList: (lesson_id: string) => Promise<Exercise[]>;
        readonly exerciseQuestionResourceCreate: (payload: CreateExerciseQuestion) => Promise<ExerciseQuestion>;
        readonly exerciseQuestionResourceList: (exercise_id: string) => Promise<ExerciseQuestion[]>;
        readonly exerciseQuestionResourceDelete: (id: string) => Promise<{}>;
        readonly exerciseQuestionResourceUpdate: (payload: CreateExerciseQuestion, id: string) => Promise<ExerciseQuestion>;
        readonly exerciseResourceStart: (payload: CreateExerciseStatus) => Promise<ExerciseStatus>;
        readonly exerciseResourceGet: (id: string) => Promise<Exercise>;
        readonly exerciseResourceUpdate: (payload: CreateExerciseConsumable, id: string) => Promise<Exercise>;
        readonly filesResourceList: () => Promise<File[]>;
        readonly filesResourceCreate: (payload: CreateFileConsumable) => Promise<CreateFileResponse>;
        readonly filesResourceComplete: (id: string) => Promise<File>;
        readonly filesResourceGet: (id: string) => Promise<File>;
        readonly assessmentAnswerResponseCreate: (payload: CreateAssessmentAnswerResponse) => Promise<AssessmentAnswerResponse>;
        readonly assessmentAnswerResponseCreateLong: (payload: CreateAssessmentLongAnswerResponse) => Promise<AssessmentAnswerResponse>;
        readonly assessmentAnswerResponseGetResponseByAnswer: (assessment_answer: string) => Promise<AssessmentAnswerResponse>;
        readonly exerciseAnswerResponseCreate: (payload: CreateExerciseAnswerResponse) => Promise<ExerciseAnswerResponse>;
        readonly assessmentGradingResourceCreate: (payload: CreateAssessmentGrading) => Promise<AssessmentReports>;
        readonly assessmentGradingResourceGetByAssessment: (assessment_id: string) => Promise<AssessmentReports[]>;
        readonly assessmentGradingResourceCompleteMarking: (report_id: string) => Promise<AssessmentReports>;
        readonly assessmentGradingResourceMark: (payload: MarkAssessment) => Promise<AssessmentReports>;
        readonly assessmentGradingResourceMarkLong: (payload: MarkLongAssessmentAnswer) => Promise<AssessmentReports>;
        readonly assessmentGradingResourceGet: (id: string) => Promise<AssessmentReports[]>;
        readonly exerciseGradingResourceCreate: (payload: CreateExerciseGrading) => Promise<ExerciseReports>;
        readonly exerciseGradingResourceGetByExercise: (exercise_id: string) => Promise<ExerciseReports[]>;
        readonly exerciseGradingResourceMark: (payload: MarkExercise) => Promise<ExerciseReports>;
        readonly exerciseGradingResourceGet: (id: string) => Promise<ExerciseReports>;
        readonly lessonsResourceDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly lessonsResourceCreate: (payload: CreateLessonConsumable) => Promise<Lesson>;
        readonly lessonsResourceGetLessonsByTopic: (topic_id: string) => Promise<Lesson[]>;
        readonly lessonsResourceGet: (id: string) => Promise<Lesson>;
        readonly lessonsResourceUpdate: (payload: CreateLessonConsumable, id: string) => Promise<Lesson>;
        readonly mediaResourceDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly mediaResourceCreate: (payload: CreateMedia) => Promise<Media>;
        readonly mediaResourceGetByPlaylist: (playlist_id: string) => Promise<Media[]>;
        readonly mediaResourceGet: (id: string) => Promise<Media>;
        readonly mediaResourceUpdate: (payload: CreateMedia, id: string) => Promise<Media>;
        readonly notesResourceDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly notesResourceCreate: (payload: CreateNotesConsumable) => Promise<Notes>;
        readonly notesResourceGetNotesByLesson: (lesson_id: string) => Promise<Notes[]>;
        readonly notesResourceGet: (id: string) => Promise<Notes>;
        readonly notesResourceUpdate: (payload: CreateNotesConsumable, id: string) => Promise<Notes>;
        readonly webhookResourcePost: (payload: EventData) => Promise<unknown>;
        readonly planGroupResourceAll: () => Promise<PlanGroup[]>;
        readonly planGroupResourceCreate: (payload: CreatePlanGroup) => Promise<PlanGroup>;
        readonly planGroupResourceGetActive: () => Promise<PlanGroup[]>;
        readonly planGroupResourceGet: (id: string) => Promise<PlanGroup>;
        readonly playlistResourceDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly playlistResourceCreate: (payload: CreatePlaylistConsumable) => Promise<Playlist>;
        readonly playlistResourceGetPlaylistsByLesson: (lesson_id: string) => Promise<Playlist[]>;
        readonly playlistResourceGet: (id: string) => Promise<Playlist>;
        readonly playlistResourceUpdate: (payload: CreatePlaylistConsumable, id: string) => Promise<Playlist>;
        readonly statsResourceGetStats: () => Promise<StatsData>;
        readonly subjectsResourceDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly subjectsResourceCreateClassroomSubject: (payload: CreateSubjects) => Promise<Subject>;
        readonly subjectsResourceListByClassroom: (classroom_id: string) => Promise<Subject[]>;
        readonly subjectsResourceGetByStudentLevel: () => Promise<Subject[]>;
        readonly subjectsResourceCreateSubject: (payload: CreateSubjects) => Promise<Subject>;
        readonly subjectsResourceGet: (id: string) => Promise<Subject>;
        readonly subjectsResourceGetByTeacher: () => Promise<Subject[]>;
        readonly subjectsResourceUpdate: (payload: CreateSubjects, id: string) => Promise<Subject>;
        readonly subscriptionResourceCreate: (payload: CreateSubscription) => Promise<PlanCost>;
        readonly subscriptionResourceCheckClassroomSub: (id: string) => Promise<ClassroomSubscription>;
        readonly subscriptionResourceClassroomSub: (payload: CreateClassroomSub) => Promise<ClassroomSubscription>;
        readonly subscriptionResourceGetSubByClassroom: (id: string) => Promise<ClassroomSubscription>;
        readonly subscriptionResourceGetByPlanGroup: (id: string) => Promise<PlanCost[]>;
        readonly subscriptionResourceUserSub: (payload: CreateUserSub) => Promise<ClassroomSubscription>;
        readonly subscriptionResourceGet: (id: string) => Promise<PlanCost>;
        readonly subscriptionResourceUpdate: (payload: CreateSubscription, id: string) => Promise<PlanCost>;
        readonly subscriptionTransactionResourceAll: () => Promise<SubscriptionTransaction[]>;
        readonly subscriptionTransactionResourceCreate: (payload: CreateTransaction) => Promise<SubscriptionTransaction>;
        readonly subscriptionTransactionResourceDelete: (id: string) => Promise<unknown>;
        readonly taskResourceListAll: () => Promise<Task[]>;
        readonly topicsResourceDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly topicsResourceCreate: (payload: CreateTopicConsumable) => Promise<Topic>;
        readonly topicsResourceGetTopicsBySubject: (subject_id: string) => Promise<Topic[]>;
        readonly topicsResourceGet: (id: string) => Promise<Topic>;
        readonly topicsResourceUpdate: (payload: CreateTopicConsumable, id: string) => Promise<Topic>;
        readonly userResourceF: () => Promise<unknown>;
        readonly userResourceGetStudent: () => Promise<Student>;
        readonly userResourceCreateStudent: (payload: StudentData) => Promise<Student>;
        readonly userResourceGetTeacher: () => Promise<Teacher>;
        readonly userResourceCreateTeacher: () => Promise<Teacher>;
        readonly utilsGetCategory: () => Promise<SubjectsCatergoryEnum[]>;
        readonly utilsGetGrades: () => Promise<Grade[]>;
        readonly utilsGetPlan: () => Promise<PlanEnum[]>;
        readonly utilsGetPlaylist: () => Promise<PlaylistMediaEnum[]>;
        readonly utilsGetRecurrenceUnit: () => Promise<RecurrenceUnit[]>;
        readonly utilsGetSubjects: () => Promise<SubjectsEnum[]>;
    };
    queryIds: {
        readonly assessmentAnswerResourceList: (q: string) => readonly ["assessmentAnswerResourceList", string];
        readonly assessmentQuestionResourceList: (assessment_id: string) => readonly ["assessmentQuestionResourceList", string];
        readonly assessmentResourceList: (subject_id: string) => readonly ["assessmentResourceList", string];
        readonly assessmentResourceGet: (id: string) => readonly ["assessmentResourceGet", string];
        readonly classroomResourceGetByStudentLevel: () => readonly ["classroomResourceGetByStudentLevel"];
        readonly classroomResourceGetTeacherId: () => readonly ["classroomResourceGetTeacherId"];
        readonly classroomResourceGet: (id: string) => readonly ["classroomResourceGet", string];
        readonly documentResourceGetByLesson: (id: string) => readonly ["documentResourceGetByLesson", string];
        readonly documentResourceGet: (id: string) => readonly ["documentResourceGet", string];
        readonly exerciseAnswerResourceList: (q: string) => readonly ["exerciseAnswerResourceList", string];
        readonly exerciseResourceList: (lesson_id: string) => readonly ["exerciseResourceList", string];
        readonly exerciseQuestionResourceList: (exercise_id: string) => readonly ["exerciseQuestionResourceList", string];
        readonly exerciseResourceGet: (id: string) => readonly ["exerciseResourceGet", string];
        readonly filesResourceList: () => readonly ["filesResourceList"];
        readonly filesResourceGet: (id: string) => readonly ["filesResourceGet", string];
        readonly assessmentAnswerResponseGetResponseByAnswer: (assessment_answer: string) => readonly ["assessmentAnswerResponseGetResponseByAnswer", string];
        readonly assessmentGradingResourceGetByAssessment: (assessment_id: string) => readonly ["assessmentGradingResourceGetByAssessment", string];
        readonly assessmentGradingResourceGet: (id: string) => readonly ["assessmentGradingResourceGet", string];
        readonly exerciseGradingResourceGetByExercise: (exercise_id: string) => readonly ["exerciseGradingResourceGetByExercise", string];
        readonly exerciseGradingResourceGet: (id: string) => readonly ["exerciseGradingResourceGet", string];
        readonly lessonsResourceGetLessonsByTopic: (topic_id: string) => readonly ["lessonsResourceGetLessonsByTopic", string];
        readonly lessonsResourceGet: (id: string) => readonly ["lessonsResourceGet", string];
        readonly mediaResourceGetByPlaylist: (playlist_id: string) => readonly ["mediaResourceGetByPlaylist", string];
        readonly mediaResourceGet: (id: string) => readonly ["mediaResourceGet", string];
        readonly notesResourceGetNotesByLesson: (lesson_id: string) => readonly ["notesResourceGetNotesByLesson", string];
        readonly notesResourceGet: (id: string) => readonly ["notesResourceGet", string];
        readonly planGroupResourceAll: () => readonly ["planGroupResourceAll"];
        readonly planGroupResourceGetActive: () => readonly ["planGroupResourceGetActive"];
        readonly planGroupResourceGet: (id: string) => readonly ["planGroupResourceGet", string];
        readonly playlistResourceGetPlaylistsByLesson: (lesson_id: string) => readonly ["playlistResourceGetPlaylistsByLesson", string];
        readonly playlistResourceGet: (id: string) => readonly ["playlistResourceGet", string];
        readonly statsResourceGetStats: () => readonly ["statsResourceGetStats"];
        readonly subjectsResourceListByClassroom: (classroom_id: string) => readonly ["subjectsResourceListByClassroom", string];
        readonly subjectsResourceGetByStudentLevel: () => readonly ["subjectsResourceGetByStudentLevel"];
        readonly subjectsResourceGet: (id: string) => readonly ["subjectsResourceGet", string];
        readonly subjectsResourceGetByTeacher: () => readonly ["subjectsResourceGetByTeacher"];
        readonly subscriptionResourceGetSubByClassroom: (id: string) => readonly ["subscriptionResourceGetSubByClassroom", string];
        readonly subscriptionResourceGetByPlanGroup: (id: string) => readonly ["subscriptionResourceGetByPlanGroup", string];
        readonly subscriptionResourceGet: (id: string) => readonly ["subscriptionResourceGet", string];
        readonly subscriptionTransactionResourceAll: () => readonly ["subscriptionTransactionResourceAll"];
        readonly taskResourceListAll: () => readonly ["taskResourceListAll"];
        readonly topicsResourceGetTopicsBySubject: (subject_id: string) => readonly ["topicsResourceGetTopicsBySubject", string];
        readonly topicsResourceGet: (id: string) => readonly ["topicsResourceGet", string];
        readonly userResourceGetStudent: () => readonly ["userResourceGetStudent"];
        readonly userResourceGetTeacher: () => readonly ["userResourceGetTeacher"];
        readonly utilsGetCategory: () => readonly ["utilsGetCategory"];
        readonly utilsGetGrades: () => readonly ["utilsGetGrades"];
        readonly utilsGetPlan: () => readonly ["utilsGetPlan"];
        readonly utilsGetPlaylist: () => readonly ["utilsGetPlaylist"];
        readonly utilsGetRecurrenceUnit: () => readonly ["utilsGetRecurrenceUnit"];
        readonly utilsGetSubjects: () => readonly ["utilsGetSubjects"];
    };
    queries: {
        readonly useAssessmentAnswerResourceList: (q: string, options?: Omit<UseQueryOptions<AssessmentAnswer[], unknown, AssessmentAnswer[], readonly ["assessmentAnswerResourceList", string]>, "queryKey" | "queryFn">) => UseQueryResult<AssessmentAnswer[], unknown>;
        readonly useAssessmentQuestionResourceList: (assessment_id: string, options?: Omit<UseQueryOptions<AssessmentQuestion[], unknown, AssessmentQuestion[], readonly ["assessmentQuestionResourceList", string]>, "queryKey" | "queryFn">) => UseQueryResult<AssessmentQuestion[], unknown>;
        readonly useAssessmentResourceList: (subject_id: string, options?: Omit<UseQueryOptions<Assessment[], unknown, Assessment[], readonly ["assessmentResourceList", string]>, "queryKey" | "queryFn">) => UseQueryResult<Assessment[], unknown>;
        readonly useAssessmentResourceGet: (id: string, options?: Omit<UseQueryOptions<Assessment, unknown, Assessment, readonly ["assessmentResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Assessment, unknown>;
        readonly useClassroomResourceGetByStudentLevel: (options?: Omit<UseQueryOptions<Classroom[], unknown, Classroom[], readonly ["classroomResourceGetByStudentLevel"]>, "queryKey" | "queryFn">) => UseQueryResult<Classroom[], unknown>;
        readonly useClassroomResourceGetTeacherId: (options?: Omit<UseQueryOptions<Classroom[], unknown, Classroom[], readonly ["classroomResourceGetTeacherId"]>, "queryKey" | "queryFn">) => UseQueryResult<Classroom[], unknown>;
        readonly useClassroomResourceGet: (id: string, options?: Omit<UseQueryOptions<Classroom, unknown, Classroom, readonly ["classroomResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Classroom, unknown>;
        readonly useDocumentResourceGetByLesson: (id: string, options?: Omit<UseQueryOptions<Document[], unknown, Document[], readonly ["documentResourceGetByLesson", string]>, "queryKey" | "queryFn">) => UseQueryResult<Document[], unknown>;
        readonly useDocumentResourceGet: (id: string, options?: Omit<UseQueryOptions<Document, unknown, Document, readonly ["documentResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Document, unknown>;
        readonly useExerciseAnswerResourceList: (q: string, options?: Omit<UseQueryOptions<ExerciseAnswer[], unknown, ExerciseAnswer[], readonly ["exerciseAnswerResourceList", string]>, "queryKey" | "queryFn">) => UseQueryResult<ExerciseAnswer[], unknown>;
        readonly useExerciseResourceList: (lesson_id: string, options?: Omit<UseQueryOptions<Exercise[], unknown, Exercise[], readonly ["exerciseResourceList", string]>, "queryKey" | "queryFn">) => UseQueryResult<Exercise[], unknown>;
        readonly useExerciseQuestionResourceList: (exercise_id: string, options?: Omit<UseQueryOptions<ExerciseQuestion[], unknown, ExerciseQuestion[], readonly ["exerciseQuestionResourceList", string]>, "queryKey" | "queryFn">) => UseQueryResult<ExerciseQuestion[], unknown>;
        readonly useExerciseResourceGet: (id: string, options?: Omit<UseQueryOptions<Exercise, unknown, Exercise, readonly ["exerciseResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Exercise, unknown>;
        readonly useFilesResourceList: (options?: Omit<UseQueryOptions<File[], unknown, File[], readonly ["filesResourceList"]>, "queryKey" | "queryFn">) => UseQueryResult<File[], unknown>;
        readonly useFilesResourceGet: (id: string, options?: Omit<UseQueryOptions<File, unknown, File, readonly ["filesResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<File, unknown>;
        readonly useAssessmentAnswerResponseGetResponseByAnswer: (assessment_answer: string, options?: Omit<UseQueryOptions<AssessmentAnswerResponse, unknown, AssessmentAnswerResponse, readonly ["assessmentAnswerResponseGetResponseByAnswer", string]>, "queryKey" | "queryFn">) => UseQueryResult<AssessmentAnswerResponse, unknown>;
        readonly useAssessmentGradingResourceGetByAssessment: (assessment_id: string, options?: Omit<UseQueryOptions<AssessmentReports[], unknown, AssessmentReports[], readonly ["assessmentGradingResourceGetByAssessment", string]>, "queryKey" | "queryFn">) => UseQueryResult<AssessmentReports[], unknown>;
        readonly useAssessmentGradingResourceGet: (id: string, options?: Omit<UseQueryOptions<AssessmentReports[], unknown, AssessmentReports[], readonly ["assessmentGradingResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<AssessmentReports[], unknown>;
        readonly useExerciseGradingResourceGetByExercise: (exercise_id: string, options?: Omit<UseQueryOptions<ExerciseReports[], unknown, ExerciseReports[], readonly ["exerciseGradingResourceGetByExercise", string]>, "queryKey" | "queryFn">) => UseQueryResult<ExerciseReports[], unknown>;
        readonly useExerciseGradingResourceGet: (id: string, options?: Omit<UseQueryOptions<ExerciseReports, unknown, ExerciseReports, readonly ["exerciseGradingResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<ExerciseReports, unknown>;
        readonly useLessonsResourceGetLessonsByTopic: (topic_id: string, options?: Omit<UseQueryOptions<Lesson[], unknown, Lesson[], readonly ["lessonsResourceGetLessonsByTopic", string]>, "queryKey" | "queryFn">) => UseQueryResult<Lesson[], unknown>;
        readonly useLessonsResourceGet: (id: string, options?: Omit<UseQueryOptions<Lesson, unknown, Lesson, readonly ["lessonsResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Lesson, unknown>;
        readonly useMediaResourceGetByPlaylist: (playlist_id: string, options?: Omit<UseQueryOptions<Media[], unknown, Media[], readonly ["mediaResourceGetByPlaylist", string]>, "queryKey" | "queryFn">) => UseQueryResult<Media[], unknown>;
        readonly useMediaResourceGet: (id: string, options?: Omit<UseQueryOptions<Media, unknown, Media, readonly ["mediaResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Media, unknown>;
        readonly useNotesResourceGetNotesByLesson: (lesson_id: string, options?: Omit<UseQueryOptions<Notes[], unknown, Notes[], readonly ["notesResourceGetNotesByLesson", string]>, "queryKey" | "queryFn">) => UseQueryResult<Notes[], unknown>;
        readonly useNotesResourceGet: (id: string, options?: Omit<UseQueryOptions<Notes, unknown, Notes, readonly ["notesResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Notes, unknown>;
        readonly usePlanGroupResourceAll: (options?: Omit<UseQueryOptions<PlanGroup[], unknown, PlanGroup[], readonly ["planGroupResourceAll"]>, "queryKey" | "queryFn">) => UseQueryResult<PlanGroup[], unknown>;
        readonly usePlanGroupResourceGetActive: (options?: Omit<UseQueryOptions<PlanGroup[], unknown, PlanGroup[], readonly ["planGroupResourceGetActive"]>, "queryKey" | "queryFn">) => UseQueryResult<PlanGroup[], unknown>;
        readonly usePlanGroupResourceGet: (id: string, options?: Omit<UseQueryOptions<PlanGroup, unknown, PlanGroup, readonly ["planGroupResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<PlanGroup, unknown>;
        readonly usePlaylistResourceGetPlaylistsByLesson: (lesson_id: string, options?: Omit<UseQueryOptions<Playlist[], unknown, Playlist[], readonly ["playlistResourceGetPlaylistsByLesson", string]>, "queryKey" | "queryFn">) => UseQueryResult<Playlist[], unknown>;
        readonly usePlaylistResourceGet: (id: string, options?: Omit<UseQueryOptions<Playlist, unknown, Playlist, readonly ["playlistResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Playlist, unknown>;
        readonly useStatsResourceGetStats: (options?: Omit<UseQueryOptions<StatsData, unknown, StatsData, readonly ["statsResourceGetStats"]>, "queryKey" | "queryFn">) => UseQueryResult<StatsData, unknown>;
        readonly useSubjectsResourceListByClassroom: (classroom_id: string, options?: Omit<UseQueryOptions<Subject[], unknown, Subject[], readonly ["subjectsResourceListByClassroom", string]>, "queryKey" | "queryFn">) => UseQueryResult<Subject[], unknown>;
        readonly useSubjectsResourceGetByStudentLevel: (options?: Omit<UseQueryOptions<Subject[], unknown, Subject[], readonly ["subjectsResourceGetByStudentLevel"]>, "queryKey" | "queryFn">) => UseQueryResult<Subject[], unknown>;
        readonly useSubjectsResourceGet: (id: string, options?: Omit<UseQueryOptions<Subject, unknown, Subject, readonly ["subjectsResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Subject, unknown>;
        readonly useSubjectsResourceGetByTeacher: (options?: Omit<UseQueryOptions<Subject[], unknown, Subject[], readonly ["subjectsResourceGetByTeacher"]>, "queryKey" | "queryFn">) => UseQueryResult<Subject[], unknown>;
        readonly useSubscriptionResourceGetSubByClassroom: (id: string, options?: Omit<UseQueryOptions<ClassroomSubscription, unknown, ClassroomSubscription, readonly ["subscriptionResourceGetSubByClassroom", string]>, "queryKey" | "queryFn">) => UseQueryResult<ClassroomSubscription, unknown>;
        readonly useSubscriptionResourceGetByPlanGroup: (id: string, options?: Omit<UseQueryOptions<PlanCost[], unknown, PlanCost[], readonly ["subscriptionResourceGetByPlanGroup", string]>, "queryKey" | "queryFn">) => UseQueryResult<PlanCost[], unknown>;
        readonly useSubscriptionResourceGet: (id: string, options?: Omit<UseQueryOptions<PlanCost, unknown, PlanCost, readonly ["subscriptionResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<PlanCost, unknown>;
        readonly useSubscriptionTransactionResourceAll: (options?: Omit<UseQueryOptions<SubscriptionTransaction[], unknown, SubscriptionTransaction[], readonly ["subscriptionTransactionResourceAll"]>, "queryKey" | "queryFn">) => UseQueryResult<SubscriptionTransaction[], unknown>;
        readonly useTaskResourceListAll: (options?: Omit<UseQueryOptions<Task[], unknown, Task[], readonly ["taskResourceListAll"]>, "queryKey" | "queryFn">) => UseQueryResult<Task[], unknown>;
        readonly useTopicsResourceGetTopicsBySubject: (subject_id: string, options?: Omit<UseQueryOptions<Topic[], unknown, Topic[], readonly ["topicsResourceGetTopicsBySubject", string]>, "queryKey" | "queryFn">) => UseQueryResult<Topic[], unknown>;
        readonly useTopicsResourceGet: (id: string, options?: Omit<UseQueryOptions<Topic, unknown, Topic, readonly ["topicsResourceGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Topic, unknown>;
        readonly useUserResourceGetStudent: (options?: Omit<UseQueryOptions<Student, unknown, Student, readonly ["userResourceGetStudent"]>, "queryKey" | "queryFn">) => UseQueryResult<Student, unknown>;
        readonly useUserResourceGetTeacher: (options?: Omit<UseQueryOptions<Teacher, unknown, Teacher, readonly ["userResourceGetTeacher"]>, "queryKey" | "queryFn">) => UseQueryResult<Teacher, unknown>;
        readonly useUtilsGetCategory: (options?: Omit<UseQueryOptions<SubjectsCatergoryEnum[], unknown, SubjectsCatergoryEnum[], readonly ["utilsGetCategory"]>, "queryKey" | "queryFn">) => UseQueryResult<SubjectsCatergoryEnum[], unknown>;
        readonly useUtilsGetGrades: (options?: Omit<UseQueryOptions<Grade[], unknown, Grade[], readonly ["utilsGetGrades"]>, "queryKey" | "queryFn">) => UseQueryResult<Grade[], unknown>;
        readonly useUtilsGetPlan: (options?: Omit<UseQueryOptions<PlanEnum[], unknown, PlanEnum[], readonly ["utilsGetPlan"]>, "queryKey" | "queryFn">) => UseQueryResult<PlanEnum[], unknown>;
        readonly useUtilsGetPlaylist: (options?: Omit<UseQueryOptions<PlaylistMediaEnum[], unknown, PlaylistMediaEnum[], readonly ["utilsGetPlaylist"]>, "queryKey" | "queryFn">) => UseQueryResult<PlaylistMediaEnum[], unknown>;
        readonly useUtilsGetRecurrenceUnit: (options?: Omit<UseQueryOptions<RecurrenceUnit[], unknown, RecurrenceUnit[], readonly ["utilsGetRecurrenceUnit"]>, "queryKey" | "queryFn">) => UseQueryResult<RecurrenceUnit[], unknown>;
        readonly useUtilsGetSubjects: (options?: Omit<UseQueryOptions<SubjectsEnum[], unknown, SubjectsEnum[], readonly ["utilsGetSubjects"]>, "queryKey" | "queryFn">) => UseQueryResult<SubjectsEnum[], unknown>;
    };
    mutations: {
        readonly useAssessmentResourceCreate: (options?: Omit<UseMutationOptions<Assessment, unknown, CreateAssessmentConsumable, unknown>, "mutationFn">) => UseMutationResult<Assessment, unknown, CreateAssessmentConsumable, unknown>;
        readonly useAssessmentResourceDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useAssessmentAnswerResourceCreate: (options?: Omit<UseMutationOptions<AssessmentAnswer, unknown, CreateAssessmentAnswer, unknown>, "mutationFn">) => UseMutationResult<AssessmentAnswer, unknown, CreateAssessmentAnswer, unknown>;
        readonly useAssessmentAnswerResourceUpdate: (id: string, options?: Omit<UseMutationOptions<AssessmentAnswer, unknown, CreateAssessmentAnswer, unknown>, "mutationFn">) => UseMutationResult<AssessmentAnswer, unknown, CreateAssessmentAnswer, unknown>;
        readonly useAssessmentAnswerResourceDelete: (id: string, options?: Omit<UseMutationOptions<{}, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<{}, unknown, unknown, unknown>;
        readonly useAssessmentResourceComplete: (options?: Omit<UseMutationOptions<AssessmentStatus, unknown, CreateAssessmentStatus, unknown>, "mutationFn">) => UseMutationResult<AssessmentStatus, unknown, CreateAssessmentStatus, unknown>;
        readonly useAssessmentQuestionResourceCreate: (options?: Omit<UseMutationOptions<AssessmentQuestion, unknown, CreateAssessmentQuestion, unknown>, "mutationFn">) => UseMutationResult<AssessmentQuestion, unknown, CreateAssessmentQuestion, unknown>;
        readonly useAssessmentQuestionResourceUpdate: (id: string, options?: Omit<UseMutationOptions<AssessmentQuestion, unknown, CreateAssessmentQuestion, unknown>, "mutationFn">) => UseMutationResult<AssessmentQuestion, unknown, CreateAssessmentQuestion, unknown>;
        readonly useAssessmentQuestionResourceDelete: (id: string, options?: Omit<UseMutationOptions<{}, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<{}, unknown, unknown, unknown>;
        readonly useAssessmentResourceStart: (options?: Omit<UseMutationOptions<AssessmentStatus, unknown, CreateAssessmentStatus, unknown>, "mutationFn">) => UseMutationResult<AssessmentStatus, unknown, CreateAssessmentStatus, unknown>;
        readonly useAssessmentResourceUpdate: (id: string, options?: Omit<UseMutationOptions<Assessment, unknown, CreateAssessmentConsumable, unknown>, "mutationFn">) => UseMutationResult<Assessment, unknown, CreateAssessmentConsumable, unknown>;
        readonly useAuthenticationResourceLogin: (options?: Omit<UseMutationOptions<TokenResponse, unknown, LoginUser, unknown>, "mutationFn">) => UseMutationResult<TokenResponse, unknown, LoginUser, unknown>;
        readonly useAuthenticationResourceRegister: (options?: Omit<UseMutationOptions<TokenResponse, unknown, CreateUser, unknown>, "mutationFn">) => UseMutationResult<TokenResponse, unknown, CreateUser, unknown>;
        readonly useClassroomResourceCreate: (options?: Omit<UseMutationOptions<Classroom, unknown, CreateClassroomConsumable, unknown>, "mutationFn">) => UseMutationResult<Classroom, unknown, CreateClassroomConsumable, unknown>;
        readonly useClassroomResourceDelete: (options?: Omit<UseMutationOptions<{}, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<{}, unknown, DeletePayload, unknown>;
        readonly useClassroomResourceUpdate: (id: string, options?: Omit<UseMutationOptions<Classroom, unknown, CreateClassroomConsumable, unknown>, "mutationFn">) => UseMutationResult<Classroom, unknown, CreateClassroomConsumable, unknown>;
        readonly useDocumentResourceCreate: (options?: Omit<UseMutationOptions<Document, unknown, CreateDocument, unknown>, "mutationFn">) => UseMutationResult<Document, unknown, CreateDocument, unknown>;
        readonly useExerciseResourceCreate: (options?: Omit<UseMutationOptions<Exercise, unknown, CreateExerciseConsumable, unknown>, "mutationFn">) => UseMutationResult<Exercise, unknown, CreateExerciseConsumable, unknown>;
        readonly useExerciseResourceDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useExerciseAnswerResourceCreate: (options?: Omit<UseMutationOptions<ExerciseAnswer, unknown, CreateExerciseAnswer, unknown>, "mutationFn">) => UseMutationResult<ExerciseAnswer, unknown, CreateExerciseAnswer, unknown>;
        readonly useExerciseAnswerResourceUpdate: (id: string, options?: Omit<UseMutationOptions<ExerciseAnswer, unknown, CreateExerciseAnswer, unknown>, "mutationFn">) => UseMutationResult<ExerciseAnswer, unknown, CreateExerciseAnswer, unknown>;
        readonly useExerciseAnswerResourceDelete: (id: string, options?: Omit<UseMutationOptions<{}, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<{}, unknown, unknown, unknown>;
        readonly useExerciseResourceComplete: (options?: Omit<UseMutationOptions<ExerciseStatus, unknown, CreateExerciseStatus, unknown>, "mutationFn">) => UseMutationResult<ExerciseStatus, unknown, CreateExerciseStatus, unknown>;
        readonly useExerciseQuestionResourceCreate: (options?: Omit<UseMutationOptions<ExerciseQuestion, unknown, CreateExerciseQuestion, unknown>, "mutationFn">) => UseMutationResult<ExerciseQuestion, unknown, CreateExerciseQuestion, unknown>;
        readonly useExerciseQuestionResourceUpdate: (id: string, options?: Omit<UseMutationOptions<ExerciseQuestion, unknown, CreateExerciseQuestion, unknown>, "mutationFn">) => UseMutationResult<ExerciseQuestion, unknown, CreateExerciseQuestion, unknown>;
        readonly useExerciseQuestionResourceDelete: (id: string, options?: Omit<UseMutationOptions<{}, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<{}, unknown, unknown, unknown>;
        readonly useExerciseResourceStart: (options?: Omit<UseMutationOptions<ExerciseStatus, unknown, CreateExerciseStatus, unknown>, "mutationFn">) => UseMutationResult<ExerciseStatus, unknown, CreateExerciseStatus, unknown>;
        readonly useExerciseResourceUpdate: (id: string, options?: Omit<UseMutationOptions<Exercise, unknown, CreateExerciseConsumable, unknown>, "mutationFn">) => UseMutationResult<Exercise, unknown, CreateExerciseConsumable, unknown>;
        readonly useFilesResourceCreate: (options?: Omit<UseMutationOptions<CreateFileResponse, unknown, CreateFileConsumable, unknown>, "mutationFn">) => UseMutationResult<CreateFileResponse, unknown, CreateFileConsumable, unknown>;
        readonly useFilesResourceComplete: (id: string, options?: Omit<UseMutationOptions<File, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<File, unknown, unknown, unknown>;
        readonly useAssessmentAnswerResponseCreate: (options?: Omit<UseMutationOptions<AssessmentAnswerResponse, unknown, CreateAssessmentAnswerResponse, unknown>, "mutationFn">) => UseMutationResult<AssessmentAnswerResponse, unknown, CreateAssessmentAnswerResponse, unknown>;
        readonly useAssessmentAnswerResponseCreateLong: (options?: Omit<UseMutationOptions<AssessmentAnswerResponse, unknown, CreateAssessmentLongAnswerResponse, unknown>, "mutationFn">) => UseMutationResult<AssessmentAnswerResponse, unknown, CreateAssessmentLongAnswerResponse, unknown>;
        readonly useExerciseAnswerResponseCreate: (options?: Omit<UseMutationOptions<ExerciseAnswerResponse, unknown, CreateExerciseAnswerResponse, unknown>, "mutationFn">) => UseMutationResult<ExerciseAnswerResponse, unknown, CreateExerciseAnswerResponse, unknown>;
        readonly useAssessmentGradingResourceCreate: (options?: Omit<UseMutationOptions<AssessmentReports, unknown, CreateAssessmentGrading, unknown>, "mutationFn">) => UseMutationResult<AssessmentReports, unknown, CreateAssessmentGrading, unknown>;
        readonly useAssessmentGradingResourceCompleteMarking: (report_id: string, options?: Omit<UseMutationOptions<AssessmentReports, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<AssessmentReports, unknown, unknown, unknown>;
        readonly useAssessmentGradingResourceMark: (options?: Omit<UseMutationOptions<AssessmentReports, unknown, MarkAssessment, unknown>, "mutationFn">) => UseMutationResult<AssessmentReports, unknown, MarkAssessment, unknown>;
        readonly useAssessmentGradingResourceMarkLong: (options?: Omit<UseMutationOptions<AssessmentReports, unknown, MarkLongAssessmentAnswer, unknown>, "mutationFn">) => UseMutationResult<AssessmentReports, unknown, MarkLongAssessmentAnswer, unknown>;
        readonly useExerciseGradingResourceCreate: (options?: Omit<UseMutationOptions<ExerciseReports, unknown, CreateExerciseGrading, unknown>, "mutationFn">) => UseMutationResult<ExerciseReports, unknown, CreateExerciseGrading, unknown>;
        readonly useExerciseGradingResourceMark: (options?: Omit<UseMutationOptions<ExerciseReports, unknown, MarkExercise, unknown>, "mutationFn">) => UseMutationResult<ExerciseReports, unknown, MarkExercise, unknown>;
        readonly useLessonsResourceCreate: (options?: Omit<UseMutationOptions<Lesson, unknown, CreateLessonConsumable, unknown>, "mutationFn">) => UseMutationResult<Lesson, unknown, CreateLessonConsumable, unknown>;
        readonly useLessonsResourceDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useLessonsResourceUpdate: (id: string, options?: Omit<UseMutationOptions<Lesson, unknown, CreateLessonConsumable, unknown>, "mutationFn">) => UseMutationResult<Lesson, unknown, CreateLessonConsumable, unknown>;
        readonly useMediaResourceCreate: (options?: Omit<UseMutationOptions<Media, unknown, CreateMedia, unknown>, "mutationFn">) => UseMutationResult<Media, unknown, CreateMedia, unknown>;
        readonly useMediaResourceDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useMediaResourceUpdate: (id: string, options?: Omit<UseMutationOptions<Media, unknown, CreateMedia, unknown>, "mutationFn">) => UseMutationResult<Media, unknown, CreateMedia, unknown>;
        readonly useNotesResourceCreate: (options?: Omit<UseMutationOptions<Notes, unknown, CreateNotesConsumable, unknown>, "mutationFn">) => UseMutationResult<Notes, unknown, CreateNotesConsumable, unknown>;
        readonly useNotesResourceDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useNotesResourceUpdate: (id: string, options?: Omit<UseMutationOptions<Notes, unknown, CreateNotesConsumable, unknown>, "mutationFn">) => UseMutationResult<Notes, unknown, CreateNotesConsumable, unknown>;
        readonly useWebhookResourcePost: (options?: Omit<UseMutationOptions<unknown, unknown, EventData, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, EventData, unknown>;
        readonly usePlanGroupResourceCreate: (options?: Omit<UseMutationOptions<PlanGroup, unknown, CreatePlanGroup, unknown>, "mutationFn">) => UseMutationResult<PlanGroup, unknown, CreatePlanGroup, unknown>;
        readonly usePlaylistResourceCreate: (options?: Omit<UseMutationOptions<Playlist, unknown, CreatePlaylistConsumable, unknown>, "mutationFn">) => UseMutationResult<Playlist, unknown, CreatePlaylistConsumable, unknown>;
        readonly usePlaylistResourceDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly usePlaylistResourceUpdate: (id: string, options?: Omit<UseMutationOptions<Playlist, unknown, CreatePlaylistConsumable, unknown>, "mutationFn">) => UseMutationResult<Playlist, unknown, CreatePlaylistConsumable, unknown>;
        readonly useSubjectsResourceDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useSubjectsResourceCreateClassroomSubject: (options?: Omit<UseMutationOptions<Subject, unknown, CreateSubjects, unknown>, "mutationFn">) => UseMutationResult<Subject, unknown, CreateSubjects, unknown>;
        readonly useSubjectsResourceCreateSubject: (options?: Omit<UseMutationOptions<Subject, unknown, CreateSubjects, unknown>, "mutationFn">) => UseMutationResult<Subject, unknown, CreateSubjects, unknown>;
        readonly useSubjectsResourceUpdate: (id: string, options?: Omit<UseMutationOptions<Subject, unknown, CreateSubjects, unknown>, "mutationFn">) => UseMutationResult<Subject, unknown, CreateSubjects, unknown>;
        readonly useSubscriptionResourceCreate: (options?: Omit<UseMutationOptions<PlanCost, unknown, CreateSubscription, unknown>, "mutationFn">) => UseMutationResult<PlanCost, unknown, CreateSubscription, unknown>;
        readonly useSubscriptionResourceCheckClassroomSub: (id: string, options?: Omit<UseMutationOptions<ClassroomSubscription, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<ClassroomSubscription, unknown, unknown, unknown>;
        readonly useSubscriptionResourceClassroomSub: (options?: Omit<UseMutationOptions<ClassroomSubscription, unknown, CreateClassroomSub, unknown>, "mutationFn">) => UseMutationResult<ClassroomSubscription, unknown, CreateClassroomSub, unknown>;
        readonly useSubscriptionResourceUserSub: (options?: Omit<UseMutationOptions<ClassroomSubscription, unknown, CreateUserSub, unknown>, "mutationFn">) => UseMutationResult<ClassroomSubscription, unknown, CreateUserSub, unknown>;
        readonly useSubscriptionResourceUpdate: (id: string, options?: Omit<UseMutationOptions<PlanCost, unknown, CreateSubscription, unknown>, "mutationFn">) => UseMutationResult<PlanCost, unknown, CreateSubscription, unknown>;
        readonly useSubscriptionTransactionResourceCreate: (options?: Omit<UseMutationOptions<SubscriptionTransaction, unknown, CreateTransaction, unknown>, "mutationFn">) => UseMutationResult<SubscriptionTransaction, unknown, CreateTransaction, unknown>;
        readonly useSubscriptionTransactionResourceDelete: (id: string, options?: Omit<UseMutationOptions<unknown, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, unknown, unknown>;
        readonly useTopicsResourceCreate: (options?: Omit<UseMutationOptions<Topic, unknown, CreateTopicConsumable, unknown>, "mutationFn">) => UseMutationResult<Topic, unknown, CreateTopicConsumable, unknown>;
        readonly useTopicsResourceDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useTopicsResourceUpdate: (id: string, options?: Omit<UseMutationOptions<Topic, unknown, CreateTopicConsumable, unknown>, "mutationFn">) => UseMutationResult<Topic, unknown, CreateTopicConsumable, unknown>;
        readonly useUserResourceF: (options?: Omit<UseMutationOptions<unknown, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, unknown, unknown>;
        readonly useUserResourceCreateStudent: (options?: Omit<UseMutationOptions<Student, unknown, StudentData, unknown>, "mutationFn">) => UseMutationResult<Student, unknown, StudentData, unknown>;
        readonly useUserResourceCreateTeacher: (options?: Omit<UseMutationOptions<Teacher, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<Teacher, unknown, unknown, unknown>;
    };
};
declare function makeRequests(axios: AxiosInstance, config?: AxiosConfig): {
    readonly assessmentResourceDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly assessmentResourceCreate: (payload: CreateAssessmentConsumable) => Promise<Assessment>;
    readonly assessmentAnswerResourceCreate: (payload: CreateAssessmentAnswer) => Promise<AssessmentAnswer>;
    readonly assessmentAnswerResourceDelete: (id: UUID) => Promise<{}>;
    readonly assessmentAnswerResourceUpdate: (payload: CreateAssessmentAnswer, id: UUID) => Promise<AssessmentAnswer>;
    readonly assessmentAnswerResourceList: (q: UUID) => Promise<AssessmentAnswer[]>;
    readonly assessmentResourceComplete: (payload: CreateAssessmentStatus) => Promise<AssessmentStatus>;
    readonly assessmentQuestionResourceCreate: (payload: CreateAssessmentQuestion) => Promise<AssessmentQuestion>;
    readonly assessmentQuestionResourceList: (assessment_id: UUID) => Promise<AssessmentQuestion[]>;
    readonly assessmentQuestionResourceDelete: (id: UUID) => Promise<{}>;
    readonly assessmentQuestionResourceUpdate: (payload: CreateAssessmentQuestion, id: UUID) => Promise<AssessmentQuestion>;
    readonly assessmentResourceList: (subject_id: UUID) => Promise<Assessment[]>;
    readonly assessmentResourceStart: (payload: CreateAssessmentStatus) => Promise<AssessmentStatus>;
    readonly assessmentResourceGet: (id: UUID) => Promise<Assessment>;
    readonly assessmentResourceUpdate: (payload: CreateAssessmentConsumable, id: UUID) => Promise<Assessment>;
    readonly authenticationResourceLogin: (payload: LoginUser) => Promise<TokenResponse>;
    readonly authenticationResourceRegister: (payload: CreateUser) => Promise<TokenResponse>;
    readonly classroomResourceDelete: (payload: DeletePayload) => Promise<{}>;
    readonly classroomResourceCreate: (payload: CreateClassroomConsumable) => Promise<Classroom>;
    readonly classroomResourceGetByStudentLevel: () => Promise<Classroom[]>;
    readonly classroomResourceGetTeacherId: () => Promise<Classroom[]>;
    readonly classroomResourceGet: (id: UUID) => Promise<Classroom>;
    readonly classroomResourceUpdate: (payload: CreateClassroomConsumable, id: UUID) => Promise<Classroom>;
    readonly documentResourceCreate: (payload: CreateDocument) => Promise<Document>;
    readonly documentResourceGetByLesson: (id: UUID) => Promise<Document[]>;
    readonly documentResourceGet: (id: UUID) => Promise<Document>;
    readonly exerciseResourceDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly exerciseResourceCreate: (payload: CreateExerciseConsumable) => Promise<Exercise>;
    readonly exerciseAnswerResourceCreate: (payload: CreateExerciseAnswer) => Promise<ExerciseAnswer>;
    readonly exerciseAnswerResourceDelete: (id: UUID) => Promise<{}>;
    readonly exerciseAnswerResourceUpdate: (payload: CreateExerciseAnswer, id: UUID) => Promise<ExerciseAnswer>;
    readonly exerciseAnswerResourceList: (q: UUID) => Promise<ExerciseAnswer[]>;
    readonly exerciseResourceComplete: (payload: CreateExerciseStatus) => Promise<ExerciseStatus>;
    readonly exerciseResourceList: (lesson_id: UUID) => Promise<Exercise[]>;
    readonly exerciseQuestionResourceCreate: (payload: CreateExerciseQuestion) => Promise<ExerciseQuestion>;
    readonly exerciseQuestionResourceList: (exercise_id: UUID) => Promise<ExerciseQuestion[]>;
    readonly exerciseQuestionResourceDelete: (id: UUID) => Promise<{}>;
    readonly exerciseQuestionResourceUpdate: (payload: CreateExerciseQuestion, id: UUID) => Promise<ExerciseQuestion>;
    readonly exerciseResourceStart: (payload: CreateExerciseStatus) => Promise<ExerciseStatus>;
    readonly exerciseResourceGet: (id: UUID) => Promise<Exercise>;
    readonly exerciseResourceUpdate: (payload: CreateExerciseConsumable, id: UUID) => Promise<Exercise>;
    readonly filesResourceList: () => Promise<File[]>;
    readonly filesResourceCreate: (payload: CreateFileConsumable) => Promise<CreateFileResponse>;
    readonly filesResourceComplete: (id: UUID) => Promise<File>;
    readonly filesResourceGet: (id: UUID) => Promise<File>;
    readonly assessmentAnswerResponseCreate: (payload: CreateAssessmentAnswerResponse) => Promise<AssessmentAnswerResponse>;
    readonly assessmentAnswerResponseCreateLong: (payload: CreateAssessmentLongAnswerResponse) => Promise<AssessmentAnswerResponse>;
    readonly assessmentAnswerResponseGetResponseByAnswer: (assessment_answer: UUID) => Promise<AssessmentAnswerResponse>;
    readonly exerciseAnswerResponseCreate: (payload: CreateExerciseAnswerResponse) => Promise<ExerciseAnswerResponse>;
    readonly assessmentGradingResourceCreate: (payload: CreateAssessmentGrading) => Promise<AssessmentReports>;
    readonly assessmentGradingResourceGetByAssessment: (assessment_id: UUID) => Promise<AssessmentReports[]>;
    readonly assessmentGradingResourceCompleteMarking: (report_id: UUID) => Promise<AssessmentReports>;
    readonly assessmentGradingResourceMark: (payload: MarkAssessment) => Promise<AssessmentReports>;
    readonly assessmentGradingResourceMarkLong: (payload: MarkLongAssessmentAnswer) => Promise<AssessmentReports>;
    readonly assessmentGradingResourceGet: (id: UUID) => Promise<AssessmentReports[]>;
    readonly exerciseGradingResourceCreate: (payload: CreateExerciseGrading) => Promise<ExerciseReports>;
    readonly exerciseGradingResourceGetByExercise: (exercise_id: UUID) => Promise<ExerciseReports[]>;
    readonly exerciseGradingResourceMark: (payload: MarkExercise) => Promise<ExerciseReports>;
    readonly exerciseGradingResourceGet: (id: UUID) => Promise<ExerciseReports>;
    readonly lessonsResourceDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly lessonsResourceCreate: (payload: CreateLessonConsumable) => Promise<Lesson>;
    readonly lessonsResourceGetLessonsByTopic: (topic_id: UUID) => Promise<Lesson[]>;
    readonly lessonsResourceGet: (id: UUID) => Promise<Lesson>;
    readonly lessonsResourceUpdate: (payload: CreateLessonConsumable, id: UUID) => Promise<Lesson>;
    readonly mediaResourceDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly mediaResourceCreate: (payload: CreateMedia) => Promise<Media>;
    readonly mediaResourceGetByPlaylist: (playlist_id: UUID) => Promise<Media[]>;
    readonly mediaResourceGet: (id: UUID) => Promise<Media>;
    readonly mediaResourceUpdate: (payload: CreateMedia, id: UUID) => Promise<Media>;
    readonly notesResourceDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly notesResourceCreate: (payload: CreateNotesConsumable) => Promise<Notes>;
    readonly notesResourceGetNotesByLesson: (lesson_id: UUID) => Promise<Notes[]>;
    readonly notesResourceGet: (id: UUID) => Promise<Notes>;
    readonly notesResourceUpdate: (payload: CreateNotesConsumable, id: UUID) => Promise<Notes>;
    readonly webhookResourcePost: (payload: EventData) => Promise<unknown>;
    readonly planGroupResourceAll: () => Promise<PlanGroup[]>;
    readonly planGroupResourceCreate: (payload: CreatePlanGroup) => Promise<PlanGroup>;
    readonly planGroupResourceGetActive: () => Promise<PlanGroup[]>;
    readonly planGroupResourceGet: (id: UUID) => Promise<PlanGroup>;
    readonly playlistResourceDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly playlistResourceCreate: (payload: CreatePlaylistConsumable) => Promise<Playlist>;
    readonly playlistResourceGetPlaylistsByLesson: (lesson_id: UUID) => Promise<Playlist[]>;
    readonly playlistResourceGet: (id: UUID) => Promise<Playlist>;
    readonly playlistResourceUpdate: (payload: CreatePlaylistConsumable, id: UUID) => Promise<Playlist>;
    readonly statsResourceGetStats: () => Promise<StatsData>;
    readonly subjectsResourceDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly subjectsResourceCreateClassroomSubject: (payload: CreateSubjects) => Promise<Subject>;
    readonly subjectsResourceListByClassroom: (classroom_id: UUID) => Promise<Subject[]>;
    readonly subjectsResourceGetByStudentLevel: () => Promise<Subject[]>;
    readonly subjectsResourceCreateSubject: (payload: CreateSubjects) => Promise<Subject>;
    readonly subjectsResourceGet: (id: UUID) => Promise<Subject>;
    readonly subjectsResourceGetByTeacher: () => Promise<Subject[]>;
    readonly subjectsResourceUpdate: (payload: CreateSubjects, id: string) => Promise<Subject>;
    readonly subscriptionResourceCreate: (payload: CreateSubscription) => Promise<PlanCost>;
    readonly subscriptionResourceCheckClassroomSub: (id: UUID) => Promise<ClassroomSubscription>;
    readonly subscriptionResourceClassroomSub: (payload: CreateClassroomSub) => Promise<ClassroomSubscription>;
    readonly subscriptionResourceGetSubByClassroom: (id: UUID) => Promise<ClassroomSubscription>;
    readonly subscriptionResourceGetByPlanGroup: (id: UUID) => Promise<PlanCost[]>;
    readonly subscriptionResourceUserSub: (payload: CreateUserSub) => Promise<ClassroomSubscription>;
    readonly subscriptionResourceGet: (id: UUID) => Promise<PlanCost>;
    readonly subscriptionResourceUpdate: (payload: CreateSubscription, id: UUID) => Promise<PlanCost>;
    readonly subscriptionTransactionResourceAll: () => Promise<SubscriptionTransaction[]>;
    readonly subscriptionTransactionResourceCreate: (payload: CreateTransaction) => Promise<SubscriptionTransaction>;
    readonly subscriptionTransactionResourceDelete: (id: UUID) => Promise<unknown>;
    readonly taskResourceListAll: () => Promise<Task[]>;
    readonly topicsResourceDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly topicsResourceCreate: (payload: CreateTopicConsumable) => Promise<Topic>;
    readonly topicsResourceGetTopicsBySubject: (subject_id: UUID) => Promise<Topic[]>;
    readonly topicsResourceGet: (id: UUID) => Promise<Topic>;
    readonly topicsResourceUpdate: (payload: CreateTopicConsumable, id: UUID) => Promise<Topic>;
    readonly userResourceF: () => Promise<unknown>;
    readonly userResourceGetStudent: () => Promise<Student>;
    readonly userResourceCreateStudent: (payload: StudentData) => Promise<Student>;
    readonly userResourceGetTeacher: () => Promise<Teacher>;
    readonly userResourceCreateTeacher: () => Promise<Teacher>;
    readonly utilsGetCategory: () => Promise<SubjectsCatergoryEnum[]>;
    readonly utilsGetGrades: () => Promise<Grade[]>;
    readonly utilsGetPlan: () => Promise<PlanEnum[]>;
    readonly utilsGetPlaylist: () => Promise<PlaylistMediaEnum[]>;
    readonly utilsGetRecurrenceUnit: () => Promise<RecurrenceUnit[]>;
    readonly utilsGetSubjects: () => Promise<SubjectsEnum[]>;
};
declare type MutationConfigs = {
    useAssessmentResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResourceDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentResourceComplete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentResourceComplete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentResourceComplete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentQuestionResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentQuestionResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentQuestionResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentQuestionResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentQuestionResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentQuestionResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentQuestionResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentQuestionResourceDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentResourceStart?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentResourceStart"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentResourceStart"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAuthenticationResourceLogin?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["authenticationResourceLogin"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["authenticationResourceLogin"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAuthenticationResourceRegister?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["authenticationResourceRegister"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["authenticationResourceRegister"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useClassroomResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["classroomResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["classroomResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useClassroomResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["classroomResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["classroomResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useClassroomResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["classroomResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["classroomResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useDocumentResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["documentResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["documentResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseAnswerResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseAnswerResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerResourceDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseResourceComplete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseResourceComplete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseResourceComplete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseQuestionResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseQuestionResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseQuestionResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseQuestionResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseQuestionResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseQuestionResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseQuestionResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseQuestionResourceDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseResourceStart?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseResourceStart"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseResourceStart"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useFilesResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["filesResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["filesResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useFilesResourceComplete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["filesResourceComplete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResponseCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResponseCreateLong?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreateLong"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreateLong"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerResponseCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerResponseCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseAnswerResponseCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentGradingResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingResourceCompleteMarking?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingResourceCompleteMarking"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingResourceMark?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingResourceMark"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentGradingResourceMark"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingResourceMarkLong?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingResourceMarkLong"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentGradingResourceMarkLong"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseGradingResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseGradingResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseGradingResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseGradingResourceMark?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseGradingResourceMark"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseGradingResourceMark"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useLessonsResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["lessonsResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["lessonsResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useLessonsResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["lessonsResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["lessonsResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useLessonsResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["lessonsResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["lessonsResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useMediaResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["mediaResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["mediaResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useMediaResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["mediaResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["mediaResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useMediaResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["mediaResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["mediaResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useNotesResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["notesResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["notesResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useNotesResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["notesResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["notesResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useNotesResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["notesResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["notesResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useWebhookResourcePost?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["webhookResourcePost"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["webhookResourcePost"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlanGroupResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["planGroupResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["planGroupResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlaylistResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["playlistResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["playlistResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlaylistResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["playlistResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["playlistResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlaylistResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["playlistResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["playlistResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsResourceCreateClassroomSubject?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsResourceCreateClassroomSubject"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsResourceCreateClassroomSubject"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsResourceCreateSubject?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsResourceCreateSubject"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsResourceCreateSubject"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceCheckClassroomSub?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceCheckClassroomSub"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceClassroomSub?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceClassroomSub"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionResourceClassroomSub"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceUserSub?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceUserSub"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionResourceUserSub"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionTransactionResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionTransactionResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionTransactionResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionTransactionResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionTransactionResourceDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useTopicsResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["topicsResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["topicsResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useTopicsResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["topicsResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["topicsResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useTopicsResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["topicsResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["topicsResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useUserResourceF?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["userResourceF"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useUserResourceCreateStudent?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["userResourceCreateStudent"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["userResourceCreateStudent"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useUserResourceCreateTeacher?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["userResourceCreateTeacher"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
};
export {};
