import type { AxiosInstance, AxiosRequestConfig } from "axios";
import { useQuery, useMutation, useQueryClient, type QueryClient, type UseMutationOptions, type UseQueryOptions, type MutationFunction, type UseMutationResult, type UseQueryResult } from "react-query";
export type Assessment = {
    id?: string;
    name?: string;
    description?: string;
    questions?: AssessmentQuestion[];
};
export type AssessmentAnswer = {
    persistent?: boolean;
    id?: string;
    answer?: string;
    correctAnswer?: boolean;
};
export type AssessmentAnswerResponse = {
    id?: string;
    student?: Student;
    marked?: boolean;
    student_response?: string;
};
export type AssessmentQuestion = {
    id?: string;
    question?: string;
    explanation?: string;
    mark?: number;
    answers?: AssessmentAnswer[];
    is_long_form?: boolean;
};
export type AssessmentReports = {
    id?: string;
    student?: Student;
    status?: MarkingStatusEnum;
    total_marks?: number;
    percentage?: number;
    totalMarkQuestions?: number;
    responses?: AssessmentAnswerResponse[];
};
export type AssessmentStatus = {
    id?: string;
    completeStatus?: CompleteStatus;
    started_at?: string;
    completed_at?: string;
    student?: Student;
};
export type Classroom = {
    id?: string;
    name?: string;
    description?: string;
    subjects?: Subject[];
    level_grade?: Grade;
    teacher?: Teacher;
};
export type ClassroomSubscription = {
    id?: string;
    classroom?: Classroom;
    subscription?: UserSubscription;
};
export type CompleteStatus = "DOING" | "DONE";
export type CreateAssessmentAnswer = {
    question?: UUID;
    answer?: string;
    correct_answer?: boolean;
};
export type CreateAssessmentAnswerResponse = {
    answer?: UUID;
    report?: UUID;
    student_response?: string;
};
export type CreateAssessmentConsumable = {
    name?: string;
    description?: string;
    subject?: UUID;
};
export type CreateAssessmentGrading = {
    assessment?: UUID;
};
export type CreateAssessmentLongAnswerResponse = {
    question?: UUID;
    report?: UUID;
    student_response?: string;
};
export type CreateAssessmentQuestion = {
    assessment?: UUID;
    question?: string;
    explanation?: string;
    mark?: number;
    is_long_form?: boolean;
};
export type CreateAssessmentStatus = {
    assessment?: UUID;
};
export type CreateClassroomConsumable = {
    name?: string;
    description?: string;
    level_grade?: Grade;
};
export type CreateClassroomSub = {
    user_sub?: UUID;
    classroom?: UUID;
};
export type CreateDocument = {
    name?: string;
    description?: string;
    file?: UUID;
    lesson?: UUID;
};
export type CreateExerciseAnswer = {
    question?: UUID;
    answer?: string;
    correct_answer?: boolean;
};
export type CreateExerciseAnswerResponse = {
    answer?: UUID;
    report?: UUID;
};
export type CreateExerciseConsumable = {
    name?: string;
    description?: string;
    lesson?: UUID;
};
export type CreateExerciseGrading = {
    exercise?: UUID;
};
export type CreateExerciseQuestion = {
    exercise?: UUID;
    question?: string;
    explanation?: string;
    mark?: number;
};
export type CreateExerciseStatus = {
    exercise?: UUID;
};
export type CreateFileConsumable = {
    name?: string;
    description?: string;
};
export type CreateFileResponse = {
    path?: URL;
    file?: string;
};
export type CreateLessonConsumable = {
    name?: string;
    description?: string;
    topic?: UUID;
};
export type CreateMedia = {
    name?: string;
    description?: string;
    file?: UUID;
    playlist?: UUID;
};
export type CreateNotesConsumable = {
    name?: string;
    description?: string;
    content?: string;
    lesson?: UUID;
};
export type CreatePlanGroup = {
    name?: string;
    description?: string;
    created_at?: string;
};
export type CreatePlaylistConsumable = {
    name?: string;
    description?: string;
    lesson?: UUID;
    type?: PlaylistMediaEnum;
};
export type CreateSubjects = {
    name?: SubjectsEnum;
    description?: string;
    level?: Grade;
    category?: SubjectsCatergoryEnum;
    classroom?: UUID;
};
export type CreateSubscription = {
    name?: string;
    description?: string;
    cost?: number;
    group?: UUID;
    recurrence_unit?: RecurrenceUnit;
    frequency?: number;
};
export type CreateTopicConsumable = {
    name?: string;
    description?: string;
    subject?: UUID;
};
export type CreateTransaction = {
    subscription?: UUID;
    transaction_date?: string;
};
export type CreateUser = {
    username?: string;
    password?: string;
    phoneNumber?: string;
    birthdate?: string;
    firstName?: string;
    lastName?: string;
    roles?: UserRoles[];
};
export type CreateUserSub = {
    name?: string;
    description?: string;
    subscription?: UUID;
    date_billing_start?: string;
};
export type Customer = {
    last_name?: string;
    first_name?: string;
    customer_code?: string;
    email?: string;
};
export type Data = {
    created_at?: string;
    paid_at?: string;
    ip_address?: string;
    customer?: Customer;
};
export type DeletePayload = {
    id?: UUID;
};
export type Document = {
    id?: string;
    file?: File;
};
export type EventData = {
    event?: string;
    data?: Data;
};
export type Exercise = {
    id?: string;
    name?: string;
    description?: string;
    questions?: ExerciseQuestion[];
};
export type ExerciseAnswer = {
    id?: string;
    answer?: string;
    correct_answer?: boolean;
};
export type ExerciseAnswerResponse = {
    id?: string;
    student?: Student;
    marked?: boolean;
    student_response?: string;
    answer?: ExerciseAnswer;
};
export type ExerciseQuestion = {
    id?: string;
    question?: string;
    explanation?: string;
    mark?: number;
    answers?: ExerciseAnswer[];
};
export type ExerciseReports = {
    id?: string;
    student?: Student;
    status?: MarkingStatusEnum;
    total_marks?: number;
    percentage?: number;
    totalMarkQuestions?: number;
    responses?: ExerciseAnswerResponse[];
};
export type ExerciseStatus = {
    id?: string;
    completeStatus?: CompleteStatus;
    started_at?: string;
    completed_at?: string;
};
export type File = {
    id?: string;
    name?: string;
    description?: string;
    created_at?: string;
    status?: FileCompleteEnum;
    path?: string;
};
export type FileCompleteEnum = "INCOMPLETE" | "COMPLETE";
export type Grade = "GRADE_ONE" | "GRADE_TWO" | "GRADE_THREE" | "GRADE_FOUR" | "GRADE_FIVE" | "GRADE_SIX" | "GRADE_SEVEN" | "FORM_ONE" | "FORM_TWO" | "FORM_THREE" | "FORM_FOUR" | "FORM_FIVE" | "FORM_SIX";
export type Lesson = {
    id?: string;
    name?: string;
    description?: string;
    topic?: Topic;
};
export type LoginUser = {
    username?: string;
    password?: string;
};
export type MarkAssessment = {
    report?: UUID;
};
export type MarkExercise = {
    report?: UUID;
};
export type MarkLongAssessmentAnswer = {
    report?: UUID;
    response?: UUID;
    mark?: number;
};
export type MarkingStatusEnum = "COMPLETE" | "MARKING" | "STARTED";
export type Media = {
    id?: string;
    file?: File;
    media_type?: PlaylistMediaEnum;
};
export type Notes = {
    id?: string;
    name?: string;
    description?: string;
    content?: string;
};
export type PlanCost = {
    id?: string;
    plan?: SubscriptionPlan;
    recurrence_period?: number;
    recurrence_unit?: RecurrenceUnit;
    cost?: number;
};
export type PlanEnum = "free" | "premium";
export type PlanGroup = {
    id?: string;
    name?: string;
    description?: string;
    status?: PlanGroupStatus;
    created_at?: string;
    plans?: PlanCost[];
};
export type PlanGroupStatus = "ACTIVE" | "INACTIVE";
export type Playlist = {
    id?: string;
    name?: string;
    lesson?: Lesson;
    type?: PlaylistMediaEnum;
};
export type PlaylistMediaEnum = "video" | "audio";
export type RecurrenceUnit = "MONTH" | "YEAR";
export type Role = {
    id?: string;
    runhareUser?: RunhareUser;
    role?: string;
};
export type RunhareUser = {
    id?: string;
    username: string;
    birthdate?: string;
    email?: string;
    phoneNumber?: string;
    firstName?: string;
    lastName?: string;
    roles?: Role[];
};
export type StatsData = {
    users?: number;
};
export type Student = {
    id?: string;
    username?: string;
    level?: Grade;
};
export type StudentData = {
    level?: Grade;
};
export type Subject = {
    id?: string;
    name?: SubjectsEnum;
    description?: string;
    plan?: PlanEnum;
    level?: Grade;
    classroom?: Classroom;
    topics?: Topic[];
    category?: SubjectsCatergoryEnum;
    teacher?: Teacher;
};
export type SubjectsCatergoryEnum = "Arts" | "Sciences" | "Commercials";
export type SubjectsEnum = "Mathematics" | "Business_Studies" | "Combined_Science" | "Physics" | "Chemistry" | "Computer_Science" | "English" | "Geography" | "Accounting" | "Economics" | "Biology" | "Commerce";
export type SubscriptionPlan = {
    id?: string;
    name?: string;
    description?: string;
    grace_period?: number;
};
export type SubscriptionTransaction = {
    id?: string;
    user?: RunhareUser;
    subscription?: PlanCost;
    date_transaction?: string;
    amount?: number;
};
export type Task = {
    id?: string;
    created_at?: string;
};
export type Teacher = {
    id?: string;
    username?: string;
    classrooms?: Classroom[];
    subjects?: Subject[];
};
export type TokenResponse = {
    token?: string;
};
export type Topic = {
    id?: string;
    name?: string;
    description?: string;
    subject?: Subject;
};
export type URL = {
    protocol?: string;
    host?: string;
    port?: number;
    file?: string;
    authority?: string;
    ref?: string;
    hashCode?: number;
    defaultPort?: number;
    content?: {};
    serializedHashCode?: number;
};
export type UUID = string;
export type UserRoles = "admin" | "teacher" | "student";
export type UserSubscription = {
    id?: string;
    subscription?: PlanCost;
    date_billing_start?: string;
    date_billing_end?: string;
    date_billing_last?: string;
    date_billing_next?: string;
    active?: boolean;
    cancelled?: boolean;
};
export type AxiosConfig = {
    paramsSerializer?: AxiosRequestConfig["paramsSerializer"];
};
export type Config = {
    mutations?: MutationConfigs;
    axios?: AxiosConfig;
};
export function initialize(axios: AxiosInstance, config?: Config) {
    const requests = makeRequests(axios, config?.axios);
    const queryIds = makeQueryIds();
    return {
        requests,
        queryIds,
        queries: makeQueries(requests, queryIds),
        mutations: makeMutations(requests, config?.mutations)
    };
}
function useRapiniMutation<TData = unknown, TError = unknown, TVariables = void, TContext = unknown>(mutationFn: MutationFunction<TData, TVariables>, config?: (queryClient: QueryClient) => Pick<UseMutationOptions<TData, TError, TVariables, TContext>, "onSuccess" | "onSettled" | "onError">, options?: Omit<UseMutationOptions<TData, TError, TVariables, TContext>, "mutationFn">): UseMutationResult<TData, TError, TVariables, TContext> {
    const { onSuccess, onError, onSettled, ...rest } = options ?? {};
    const queryClient = useQueryClient();
    const conf = config?.(queryClient);
    const mutationOptions: typeof options = {
        onSuccess: (data: TData, variables: TVariables, context?: TContext) => {
            conf?.onSuccess?.(data, variables, context);
            onSuccess?.(data, variables, context);
        },
        onError: (error: TError, variables: TVariables, context?: TContext) => {
            conf?.onError?.(error, variables, context);
            onError?.(error, variables, context);
        },
        onSettled: (data: TData | undefined, error: TError | null, variables: TVariables, context?: TContext) => {
            conf?.onSettled?.(data, error, variables, context);
            onSettled?.(data, error, variables, context);
        },
        ...rest
    };
    return useMutation(mutationFn, mutationOptions);
}
function nullIfUndefined<T>(value: T): T | null {
    return typeof value === "undefined" ? null : value;
}
function makeQueryIds() {
    return {
        assessmentAnswerResourceList: (q: UUID) => ["assessmentAnswerResourceList", q] as const,
        assessmentQuestionResourceList: (assessment_id: UUID) => ["assessmentQuestionResourceList", assessment_id] as const,
        assessmentResourceList: (subject_id: UUID) => ["assessmentResourceList", subject_id] as const,
        assessmentResourceGet: (id: UUID) => ["assessmentResourceGet", id] as const,
        classroomResourceGetByStudentLevel: () => ["classroomResourceGetByStudentLevel"] as const,
        classroomResourceGetTeacherId: () => ["classroomResourceGetTeacherId"] as const,
        classroomResourceGet: (id: UUID) => ["classroomResourceGet", id] as const,
        documentResourceGetByLesson: (id: UUID) => ["documentResourceGetByLesson", id] as const,
        documentResourceGet: (id: UUID) => ["documentResourceGet", id] as const,
        exerciseAnswerResourceList: (q: UUID) => ["exerciseAnswerResourceList", q] as const,
        exerciseResourceList: (lesson_id: UUID) => ["exerciseResourceList", lesson_id] as const,
        exerciseQuestionResourceList: (exercise_id: UUID) => ["exerciseQuestionResourceList", exercise_id] as const,
        exerciseResourceGet: (id: UUID) => ["exerciseResourceGet", id] as const,
        filesResourceList: () => ["filesResourceList"] as const,
        filesResourceGet: (id: UUID) => ["filesResourceGet", id] as const,
        assessmentAnswerResponseGetResponseByAnswer: (assessment_answer: UUID) => ["assessmentAnswerResponseGetResponseByAnswer", assessment_answer] as const,
        assessmentGradingResourceGetByAssessment: (assessment_id: UUID) => ["assessmentGradingResourceGetByAssessment", assessment_id] as const,
        assessmentGradingResourceGet: (id: UUID) => ["assessmentGradingResourceGet", id] as const,
        exerciseGradingResourceGetByExercise: (exercise_id: UUID) => ["exerciseGradingResourceGetByExercise", exercise_id] as const,
        exerciseGradingResourceGet: (id: UUID) => ["exerciseGradingResourceGet", id] as const,
        lessonsResourceGetLessonsByTopic: (topic_id: UUID) => ["lessonsResourceGetLessonsByTopic", topic_id] as const,
        lessonsResourceGet: (id: UUID) => ["lessonsResourceGet", id] as const,
        mediaResourceGetByPlaylist: (playlist_id: UUID) => ["mediaResourceGetByPlaylist", playlist_id] as const,
        mediaResourceGet: (id: UUID) => ["mediaResourceGet", id] as const,
        notesResourceGetNotesByLesson: (lesson_id: UUID) => ["notesResourceGetNotesByLesson", lesson_id] as const,
        notesResourceGet: (id: UUID) => ["notesResourceGet", id] as const,
        planGroupResourceAll: () => ["planGroupResourceAll"] as const,
        planGroupResourceGetActive: () => ["planGroupResourceGetActive"] as const,
        planGroupResourceGet: (id: UUID) => ["planGroupResourceGet", id] as const,
        playlistResourceGetPlaylistsByLesson: (lesson_id: UUID) => ["playlistResourceGetPlaylistsByLesson", lesson_id] as const,
        playlistResourceGet: (id: UUID) => ["playlistResourceGet", id] as const,
        statsResourceGetStats: () => ["statsResourceGetStats"] as const,
        subjectsResourceListByClassroom: (classroom_id: UUID) => ["subjectsResourceListByClassroom", classroom_id] as const,
        subjectsResourceGetByStudentLevel: () => ["subjectsResourceGetByStudentLevel"] as const,
        subjectsResourceGet: (id: UUID) => ["subjectsResourceGet", id] as const,
        subjectsResourceGetByTeacher: () => ["subjectsResourceGetByTeacher"] as const,
        subscriptionResourceGetSubByClassroom: (id: UUID) => ["subscriptionResourceGetSubByClassroom", id] as const,
        subscriptionResourceGetByPlanGroup: (id: UUID) => ["subscriptionResourceGetByPlanGroup", id] as const,
        subscriptionResourceGet: (id: UUID) => ["subscriptionResourceGet", id] as const,
        subscriptionTransactionResourceAll: () => ["subscriptionTransactionResourceAll"] as const,
        taskResourceListAll: () => ["taskResourceListAll"] as const,
        topicsResourceGetTopicsBySubject: (subject_id: UUID) => ["topicsResourceGetTopicsBySubject", subject_id] as const,
        topicsResourceGet: (id: UUID) => ["topicsResourceGet", id] as const,
        userResourceGetStudent: () => ["userResourceGetStudent"] as const,
        userResourceGetTeacher: () => ["userResourceGetTeacher"] as const,
        utilsGetCategory: () => ["utilsGetCategory"] as const,
        utilsGetGrades: () => ["utilsGetGrades"] as const,
        utilsGetPlan: () => ["utilsGetPlan"] as const,
        utilsGetPlaylist: () => ["utilsGetPlaylist"] as const,
        utilsGetRecurrenceUnit: () => ["utilsGetRecurrenceUnit"] as const,
        utilsGetSubjects: () => ["utilsGetSubjects"] as const
    } as const;
}
function makeRequests(axios: AxiosInstance, config?: AxiosConfig) {
    return {
        assessmentResourceDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/assessments`,
            data: payload
        }).then(res => res.data),
        assessmentResourceCreate: (payload: CreateAssessmentConsumable) => axios.request<Assessment>({
            method: "post",
            url: `/v1/api/assessments`,
            data: payload
        }).then(res => res.data),
        assessmentAnswerResourceCreate: (payload: CreateAssessmentAnswer) => axios.request<AssessmentAnswer>({
            method: "post",
            url: `/v1/api/assessments/a`,
            data: payload
        }).then(res => res.data),
        assessmentAnswerResourceDelete: (id: UUID) => axios.request<{}>({
            method: "delete",
            url: `/v1/api/assessments/a/${id}`
        }).then(res => res.data),
        assessmentAnswerResourceUpdate: (payload: CreateAssessmentAnswer, id: UUID) => axios.request<AssessmentAnswer>({
            method: "put",
            url: `/v1/api/assessments/a/${id}`,
            data: payload
        }).then(res => res.data),
        assessmentAnswerResourceList: (q: UUID) => axios.request<AssessmentAnswer[]>({
            method: "get",
            url: `/v1/api/assessments/a/${q}`
        }).then(res => res.data),
        assessmentResourceComplete: (payload: CreateAssessmentStatus) => axios.request<AssessmentStatus>({
            method: "post",
            url: `/v1/api/assessments/complete`,
            data: payload
        }).then(res => res.data),
        assessmentQuestionResourceCreate: (payload: CreateAssessmentQuestion) => axios.request<AssessmentQuestion>({
            method: "post",
            url: `/v1/api/assessments/q`,
            data: payload
        }).then(res => res.data),
        assessmentQuestionResourceList: (assessment_id: UUID) => axios.request<AssessmentQuestion[]>({
            method: "get",
            url: `/v1/api/assessments/q/${assessment_id}`
        }).then(res => res.data),
        assessmentQuestionResourceDelete: (id: UUID) => axios.request<{}>({
            method: "delete",
            url: `/v1/api/assessments/q/${id}`
        }).then(res => res.data),
        assessmentQuestionResourceUpdate: (payload: CreateAssessmentQuestion, id: UUID) => axios.request<AssessmentQuestion>({
            method: "put",
            url: `/v1/api/assessments/q/${id}`,
            data: payload
        }).then(res => res.data),
        assessmentResourceList: (subject_id: UUID) => axios.request<Assessment[]>({
            method: "get",
            url: `/v1/api/assessments/s/${subject_id}`
        }).then(res => res.data),
        assessmentResourceStart: (payload: CreateAssessmentStatus) => axios.request<AssessmentStatus>({
            method: "post",
            url: `/v1/api/assessments/start`,
            data: payload
        }).then(res => res.data),
        assessmentResourceGet: (id: UUID) => axios.request<Assessment>({
            method: "get",
            url: `/v1/api/assessments/${id}`
        }).then(res => res.data),
        assessmentResourceUpdate: (payload: CreateAssessmentConsumable, id: UUID) => axios.request<Assessment>({
            method: "put",
            url: `/v1/api/assessments/${id}`,
            data: payload
        }).then(res => res.data),
        authenticationResourceLogin: (payload: LoginUser) => axios.request<TokenResponse>({
            method: "post",
            url: `/v1/api/auth/login`,
            data: payload
        }).then(res => res.data),
        authenticationResourceRegister: (payload: CreateUser) => axios.request<TokenResponse>({
            method: "post",
            url: `/v1/api/auth/register`,
            data: payload
        }).then(res => res.data),
        classroomResourceDelete: (payload: DeletePayload) => axios.request<{}>({
            method: "delete",
            url: `/v1/api/classrooms`,
            data: payload
        }).then(res => res.data),
        classroomResourceCreate: (payload: CreateClassroomConsumable) => axios.request<Classroom>({
            method: "post",
            url: `/v1/api/classrooms`,
            data: payload
        }).then(res => res.data),
        classroomResourceGetByStudentLevel: () => axios.request<Classroom[]>({
            method: "get",
            url: `/v1/api/classrooms/s`
        }).then(res => res.data),
        classroomResourceGetTeacherId: () => axios.request<Classroom[]>({
            method: "get",
            url: `/v1/api/classrooms/t`
        }).then(res => res.data),
        classroomResourceGet: (id: UUID) => axios.request<Classroom>({
            method: "get",
            url: `/v1/api/classrooms/${id}`
        }).then(res => res.data),
        classroomResourceUpdate: (payload: CreateClassroomConsumable, id: UUID) => axios.request<Classroom>({
            method: "put",
            url: `/v1/api/classrooms/${id}`,
            data: payload
        }).then(res => res.data),
        documentResourceCreate: (payload: CreateDocument) => axios.request<Document>({
            method: "post",
            url: `/v1/api/document`,
            data: payload
        }).then(res => res.data),
        documentResourceGetByLesson: (id: UUID) => axios.request<Document[]>({
            method: "get",
            url: `/v1/api/document/l/${id}`
        }).then(res => res.data),
        documentResourceGet: (id: UUID) => axios.request<Document>({
            method: "get",
            url: `/v1/api/document/${id}`
        }).then(res => res.data),
        exerciseResourceDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/exercises`,
            data: payload
        }).then(res => res.data),
        exerciseResourceCreate: (payload: CreateExerciseConsumable) => axios.request<Exercise>({
            method: "post",
            url: `/v1/api/exercises`,
            data: payload
        }).then(res => res.data),
        exerciseAnswerResourceCreate: (payload: CreateExerciseAnswer) => axios.request<ExerciseAnswer>({
            method: "post",
            url: `/v1/api/exercises/a`,
            data: payload
        }).then(res => res.data),
        exerciseAnswerResourceDelete: (id: UUID) => axios.request<{}>({
            method: "delete",
            url: `/v1/api/exercises/a/${id}`
        }).then(res => res.data),
        exerciseAnswerResourceUpdate: (payload: CreateExerciseAnswer, id: UUID) => axios.request<ExerciseAnswer>({
            method: "put",
            url: `/v1/api/exercises/a/${id}`,
            data: payload
        }).then(res => res.data),
        exerciseAnswerResourceList: (q: UUID) => axios.request<ExerciseAnswer[]>({
            method: "get",
            url: `/v1/api/exercises/a/${q}`
        }).then(res => res.data),
        exerciseResourceComplete: (payload: CreateExerciseStatus) => axios.request<ExerciseStatus>({
            method: "post",
            url: `/v1/api/exercises/complete`,
            data: payload
        }).then(res => res.data),
        exerciseResourceList: (lesson_id: UUID) => axios.request<Exercise[]>({
            method: "get",
            url: `/v1/api/exercises/l/${lesson_id}`
        }).then(res => res.data),
        exerciseQuestionResourceCreate: (payload: CreateExerciseQuestion) => axios.request<ExerciseQuestion>({
            method: "post",
            url: `/v1/api/exercises/q`,
            data: payload
        }).then(res => res.data),
        exerciseQuestionResourceList: (exercise_id: UUID) => axios.request<ExerciseQuestion[]>({
            method: "get",
            url: `/v1/api/exercises/q/${exercise_id}`
        }).then(res => res.data),
        exerciseQuestionResourceDelete: (id: UUID) => axios.request<{}>({
            method: "delete",
            url: `/v1/api/exercises/q/${id}`
        }).then(res => res.data),
        exerciseQuestionResourceUpdate: (payload: CreateExerciseQuestion, id: UUID) => axios.request<ExerciseQuestion>({
            method: "put",
            url: `/v1/api/exercises/q/${id}`,
            data: payload
        }).then(res => res.data),
        exerciseResourceStart: (payload: CreateExerciseStatus) => axios.request<ExerciseStatus>({
            method: "post",
            url: `/v1/api/exercises/start`,
            data: payload
        }).then(res => res.data),
        exerciseResourceGet: (id: UUID) => axios.request<Exercise>({
            method: "get",
            url: `/v1/api/exercises/${id}`
        }).then(res => res.data),
        exerciseResourceUpdate: (payload: CreateExerciseConsumable, id: UUID) => axios.request<Exercise>({
            method: "put",
            url: `/v1/api/exercises/${id}`,
            data: payload
        }).then(res => res.data),
        filesResourceList: () => axios.request<File[]>({
            method: "get",
            url: `/v1/api/files`
        }).then(res => res.data),
        filesResourceCreate: (payload: CreateFileConsumable) => axios.request<CreateFileResponse>({
            method: "post",
            url: `/v1/api/files`,
            data: payload
        }).then(res => res.data),
        filesResourceComplete: (id: UUID) => axios.request<File>({
            method: "post",
            url: `/v1/api/files/complete/${id}`
        }).then(res => res.data),
        filesResourceGet: (id: UUID) => axios.request<File>({
            method: "get",
            url: `/v1/api/files/${id}`
        }).then(res => res.data),
        assessmentAnswerResponseCreate: (payload: CreateAssessmentAnswerResponse) => axios.request<AssessmentAnswerResponse>({
            method: "post",
            url: `/v1/api/g/answer/a`,
            data: payload
        }).then(res => res.data),
        assessmentAnswerResponseCreateLong: (payload: CreateAssessmentLongAnswerResponse) => axios.request<AssessmentAnswerResponse>({
            method: "post",
            url: `/v1/api/g/answer/a/l`,
            data: payload
        }).then(res => res.data),
        assessmentAnswerResponseGetResponseByAnswer: (assessment_answer: UUID) => axios.request<AssessmentAnswerResponse>({
            method: "get",
            url: `/v1/api/g/answer/a/${assessment_answer}`
        }).then(res => res.data),
        exerciseAnswerResponseCreate: (payload: CreateExerciseAnswerResponse) => axios.request<ExerciseAnswerResponse>({
            method: "post",
            url: `/v1/api/g/answer/e`,
            data: payload
        }).then(res => res.data),
        assessmentGradingResourceCreate: (payload: CreateAssessmentGrading) => axios.request<AssessmentReports>({
            method: "post",
            url: `/v1/api/grading/a`,
            data: payload
        }).then(res => res.data),
        assessmentGradingResourceGetByAssessment: (assessment_id: UUID) => axios.request<AssessmentReports[]>({
            method: "get",
            url: `/v1/api/grading/a/a/${assessment_id}`
        }).then(res => res.data),
        assessmentGradingResourceCompleteMarking: (report_id: UUID) => axios.request<AssessmentReports>({
            method: "post",
            url: `/v1/api/grading/a/complete/marking/${report_id}`
        }).then(res => res.data),
        assessmentGradingResourceMark: (payload: MarkAssessment) => axios.request<AssessmentReports>({
            method: "post",
            url: `/v1/api/grading/a/mark`,
            data: payload
        }).then(res => res.data),
        assessmentGradingResourceMarkLong: (payload: MarkLongAssessmentAnswer) => axios.request<AssessmentReports>({
            method: "post",
            url: `/v1/api/grading/a/mark/l`,
            data: payload
        }).then(res => res.data),
        assessmentGradingResourceGet: (id: UUID) => axios.request<AssessmentReports[]>({
            method: "get",
            url: `/v1/api/grading/a/${id}`
        }).then(res => res.data),
        exerciseGradingResourceCreate: (payload: CreateExerciseGrading) => axios.request<ExerciseReports>({
            method: "post",
            url: `/v1/api/grading/e`,
            data: payload
        }).then(res => res.data),
        exerciseGradingResourceGetByExercise: (exercise_id: UUID) => axios.request<ExerciseReports[]>({
            method: "get",
            url: `/v1/api/grading/e/e/${exercise_id}`
        }).then(res => res.data),
        exerciseGradingResourceMark: (payload: MarkExercise) => axios.request<ExerciseReports>({
            method: "post",
            url: `/v1/api/grading/e/mark`,
            data: payload
        }).then(res => res.data),
        exerciseGradingResourceGet: (id: UUID) => axios.request<ExerciseReports>({
            method: "get",
            url: `/v1/api/grading/e/${id}`
        }).then(res => res.data),
        lessonsResourceDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/lessons`,
            data: payload
        }).then(res => res.data),
        lessonsResourceCreate: (payload: CreateLessonConsumable) => axios.request<Lesson>({
            method: "post",
            url: `/v1/api/lessons`,
            data: payload
        }).then(res => res.data),
        lessonsResourceGetLessonsByTopic: (topic_id: UUID) => axios.request<Lesson[]>({
            method: "get",
            url: `/v1/api/lessons/t/${topic_id}`
        }).then(res => res.data),
        lessonsResourceGet: (id: UUID) => axios.request<Lesson>({
            method: "get",
            url: `/v1/api/lessons/${id}`
        }).then(res => res.data),
        lessonsResourceUpdate: (payload: CreateLessonConsumable, id: UUID) => axios.request<Lesson>({
            method: "put",
            url: `/v1/api/lessons/${id}`,
            data: payload
        }).then(res => res.data),
        mediaResourceDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/media`,
            data: payload
        }).then(res => res.data),
        mediaResourceCreate: (payload: CreateMedia) => axios.request<Media>({
            method: "post",
            url: `/v1/api/media`,
            data: payload
        }).then(res => res.data),
        mediaResourceGetByPlaylist: (playlist_id: UUID) => axios.request<Media[]>({
            method: "get",
            url: `/v1/api/media/p/${playlist_id}`
        }).then(res => res.data),
        mediaResourceGet: (id: UUID) => axios.request<Media>({
            method: "get",
            url: `/v1/api/media/${id}`
        }).then(res => res.data),
        mediaResourceUpdate: (payload: CreateMedia, id: UUID) => axios.request<Media>({
            method: "put",
            url: `/v1/api/media/${id}`,
            data: payload
        }).then(res => res.data),
        notesResourceDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/notes`,
            data: payload
        }).then(res => res.data),
        notesResourceCreate: (payload: CreateNotesConsumable) => axios.request<Notes>({
            method: "post",
            url: `/v1/api/notes`,
            data: payload
        }).then(res => res.data),
        notesResourceGetNotesByLesson: (lesson_id: UUID) => axios.request<Notes[]>({
            method: "get",
            url: `/v1/api/notes/n/${lesson_id}`
        }).then(res => res.data),
        notesResourceGet: (id: UUID) => axios.request<Notes>({
            method: "get",
            url: `/v1/api/notes/${id}`
        }).then(res => res.data),
        notesResourceUpdate: (payload: CreateNotesConsumable, id: UUID) => axios.request<Notes>({
            method: "put",
            url: `/v1/api/notes/${id}`,
            data: payload
        }).then(res => res.data),
        webhookResourcePost: (payload: EventData) => axios.request<unknown>({
            method: "post",
            url: `/v1/api/paystack-webhook`,
            data: payload
        }).then(res => res.data),
        planGroupResourceAll: () => axios.request<PlanGroup[]>({
            method: "get",
            url: `/v1/api/plan_group`
        }).then(res => res.data),
        planGroupResourceCreate: (payload: CreatePlanGroup) => axios.request<PlanGroup>({
            method: "post",
            url: `/v1/api/plan_group`,
            data: payload
        }).then(res => res.data),
        planGroupResourceGetActive: () => axios.request<PlanGroup[]>({
            method: "get",
            url: `/v1/api/plan_group/active`
        }).then(res => res.data),
        planGroupResourceGet: (id: UUID) => axios.request<PlanGroup>({
            method: "get",
            url: `/v1/api/plan_group/${id}`
        }).then(res => res.data),
        playlistResourceDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/playlist`,
            data: payload
        }).then(res => res.data),
        playlistResourceCreate: (payload: CreatePlaylistConsumable) => axios.request<Playlist>({
            method: "post",
            url: `/v1/api/playlist`,
            data: payload
        }).then(res => res.data),
        playlistResourceGetPlaylistsByLesson: (lesson_id: UUID) => axios.request<Playlist[]>({
            method: "get",
            url: `/v1/api/playlist/l/${lesson_id}`
        }).then(res => res.data),
        playlistResourceGet: (id: UUID) => axios.request<Playlist>({
            method: "get",
            url: `/v1/api/playlist/${id}`
        }).then(res => res.data),
        playlistResourceUpdate: (payload: CreatePlaylistConsumable, id: UUID) => axios.request<Playlist>({
            method: "put",
            url: `/v1/api/playlist/${id}`,
            data: payload
        }).then(res => res.data),
        statsResourceGetStats: () => axios.request<StatsData>({
            method: "get",
            url: `/v1/api/stats`
        }).then(res => res.data),
        subjectsResourceDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/subjects`,
            data: payload
        }).then(res => res.data),
        subjectsResourceCreateClassroomSubject: (payload: CreateSubjects) => axios.request<Subject>({
            method: "post",
            url: `/v1/api/subjects/c`,
            data: payload
        }).then(res => res.data),
        subjectsResourceListByClassroom: (classroom_id: UUID) => axios.request<Subject[]>({
            method: "get",
            url: `/v1/api/subjects/c/${classroom_id}`
        }).then(res => res.data),
        subjectsResourceGetByStudentLevel: () => axios.request<Subject[]>({
            method: "get",
            url: `/v1/api/subjects/s`
        }).then(res => res.data),
        subjectsResourceCreateSubject: (payload: CreateSubjects) => axios.request<Subject>({
            method: "post",
            url: `/v1/api/subjects/s`,
            data: payload
        }).then(res => res.data),
        subjectsResourceGet: (id: UUID) => axios.request<Subject>({
            method: "get",
            url: `/v1/api/subjects/s/${id}`
        }).then(res => res.data),
        subjectsResourceGetByTeacher: () => axios.request<Subject[]>({
            method: "get",
            url: `/v1/api/subjects/t`
        }).then(res => res.data),
        subjectsResourceUpdate: (payload: CreateSubjects, id: string) => axios.request<Subject>({
            method: "put",
            url: `/v1/api/subjects/${id}`,
            data: payload
        }).then(res => res.data),
        subscriptionResourceCreate: (payload: CreateSubscription) => axios.request<PlanCost>({
            method: "post",
            url: `/v1/api/subscription`,
            data: payload
        }).then(res => res.data),
        subscriptionResourceCheckClassroomSub: (id: UUID) => axios.request<ClassroomSubscription>({
            method: "post",
            url: `/v1/api/subscription/check_classroom_sub/${id}`
        }).then(res => res.data),
        subscriptionResourceClassroomSub: (payload: CreateClassroomSub) => axios.request<ClassroomSubscription>({
            method: "post",
            url: `/v1/api/subscription/classroom_sub`,
            data: payload
        }).then(res => res.data),
        subscriptionResourceGetSubByClassroom: (id: UUID) => axios.request<ClassroomSubscription>({
            method: "get",
            url: `/v1/api/subscription/classroom_sub/${id}`
        }).then(res => res.data),
        subscriptionResourceGetByPlanGroup: (id: UUID) => axios.request<PlanCost[]>({
            method: "get",
            url: `/v1/api/subscription/group_id/${id}`
        }).then(res => res.data),
        subscriptionResourceUserSub: (payload: CreateUserSub) => axios.request<ClassroomSubscription>({
            method: "post",
            url: `/v1/api/subscription/user_sub`,
            data: payload
        }).then(res => res.data),
        subscriptionResourceGet: (id: UUID) => axios.request<PlanCost>({
            method: "get",
            url: `/v1/api/subscription/${id}`
        }).then(res => res.data),
        subscriptionResourceUpdate: (payload: CreateSubscription, id: UUID) => axios.request<PlanCost>({
            method: "put",
            url: `/v1/api/subscription/${id}`,
            data: payload
        }).then(res => res.data),
        subscriptionTransactionResourceAll: () => axios.request<SubscriptionTransaction[]>({
            method: "get",
            url: `/v1/api/subscription_transaction`
        }).then(res => res.data),
        subscriptionTransactionResourceCreate: (payload: CreateTransaction) => axios.request<SubscriptionTransaction>({
            method: "post",
            url: `/v1/api/subscription_transaction`,
            data: payload
        }).then(res => res.data),
        subscriptionTransactionResourceDelete: (id: UUID) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/subscription_transaction/${id}`
        }).then(res => res.data),
        taskResourceListAll: () => axios.request<Task[]>({
            method: "get",
            url: `/v1/api/tasks`
        }).then(res => res.data),
        topicsResourceDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/topics`,
            data: payload
        }).then(res => res.data),
        topicsResourceCreate: (payload: CreateTopicConsumable) => axios.request<Topic>({
            method: "post",
            url: `/v1/api/topics`,
            data: payload
        }).then(res => res.data),
        topicsResourceGetTopicsBySubject: (subject_id: UUID) => axios.request<Topic[]>({
            method: "get",
            url: `/v1/api/topics/s/${subject_id}`
        }).then(res => res.data),
        topicsResourceGet: (id: UUID) => axios.request<Topic>({
            method: "get",
            url: `/v1/api/topics/${id}`
        }).then(res => res.data),
        topicsResourceUpdate: (payload: CreateTopicConsumable, id: UUID) => axios.request<Topic>({
            method: "put",
            url: `/v1/api/topics/${id}`,
            data: payload
        }).then(res => res.data),
        userResourceF: () => axios.request<unknown>({
            method: "post",
            url: `/v1/api/user/f`
        }).then(res => res.data),
        userResourceGetStudent: () => axios.request<Student>({
            method: "get",
            url: `/v1/api/user/student`
        }).then(res => res.data),
        userResourceCreateStudent: (payload: StudentData) => axios.request<Student>({
            method: "post",
            url: `/v1/api/user/student`,
            data: payload
        }).then(res => res.data),
        userResourceGetTeacher: () => axios.request<Teacher>({
            method: "get",
            url: `/v1/api/user/teacher`
        }).then(res => res.data),
        userResourceCreateTeacher: () => axios.request<Teacher>({
            method: "post",
            url: `/v1/api/user/teacher`
        }).then(res => res.data),
        utilsGetCategory: () => axios.request<SubjectsCatergoryEnum[]>({
            method: "get",
            url: `/v1/api/utils/category`
        }).then(res => res.data),
        utilsGetGrades: () => axios.request<Grade[]>({
            method: "get",
            url: `/v1/api/utils/grade`
        }).then(res => res.data),
        utilsGetPlan: () => axios.request<PlanEnum[]>({
            method: "get",
            url: `/v1/api/utils/plan`
        }).then(res => res.data),
        utilsGetPlaylist: () => axios.request<PlaylistMediaEnum[]>({
            method: "get",
            url: `/v1/api/utils/playlist`
        }).then(res => res.data),
        utilsGetRecurrenceUnit: () => axios.request<RecurrenceUnit[]>({
            method: "get",
            url: `/v1/api/utils/recurrence`
        }).then(res => res.data),
        utilsGetSubjects: () => axios.request<SubjectsEnum[]>({
            method: "get",
            url: `/v1/api/utils/subject`
        }).then(res => res.data)
    } as const;
}
function makeQueries(requests: ReturnType<typeof makeRequests>, queryIds: ReturnType<typeof makeQueryIds>) {
    return {
        useAssessmentAnswerResourceList: (q: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentAnswerResourceList>>, unknown, Awaited<ReturnType<typeof requests.assessmentAnswerResourceList>>, ReturnType<(typeof queryIds)["assessmentAnswerResourceList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentAnswerResourceList>>, unknown> => useQuery(queryIds.assessmentAnswerResourceList(q), () => requests.assessmentAnswerResourceList(q), options),
        useAssessmentQuestionResourceList: (assessment_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentQuestionResourceList>>, unknown, Awaited<ReturnType<typeof requests.assessmentQuestionResourceList>>, ReturnType<(typeof queryIds)["assessmentQuestionResourceList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentQuestionResourceList>>, unknown> => useQuery(queryIds.assessmentQuestionResourceList(assessment_id), () => requests.assessmentQuestionResourceList(assessment_id), options),
        useAssessmentResourceList: (subject_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentResourceList>>, unknown, Awaited<ReturnType<typeof requests.assessmentResourceList>>, ReturnType<(typeof queryIds)["assessmentResourceList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentResourceList>>, unknown> => useQuery(queryIds.assessmentResourceList(subject_id), () => requests.assessmentResourceList(subject_id), options),
        useAssessmentResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentResourceGet>>, unknown, Awaited<ReturnType<typeof requests.assessmentResourceGet>>, ReturnType<(typeof queryIds)["assessmentResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentResourceGet>>, unknown> => useQuery(queryIds.assessmentResourceGet(id), () => requests.assessmentResourceGet(id), options),
        useClassroomResourceGetByStudentLevel: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.classroomResourceGetByStudentLevel>>, unknown, Awaited<ReturnType<typeof requests.classroomResourceGetByStudentLevel>>, ReturnType<(typeof queryIds)["classroomResourceGetByStudentLevel"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.classroomResourceGetByStudentLevel>>, unknown> => useQuery(queryIds.classroomResourceGetByStudentLevel(), () => requests.classroomResourceGetByStudentLevel(), options),
        useClassroomResourceGetTeacherId: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.classroomResourceGetTeacherId>>, unknown, Awaited<ReturnType<typeof requests.classroomResourceGetTeacherId>>, ReturnType<(typeof queryIds)["classroomResourceGetTeacherId"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.classroomResourceGetTeacherId>>, unknown> => useQuery(queryIds.classroomResourceGetTeacherId(), () => requests.classroomResourceGetTeacherId(), options),
        useClassroomResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.classroomResourceGet>>, unknown, Awaited<ReturnType<typeof requests.classroomResourceGet>>, ReturnType<(typeof queryIds)["classroomResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.classroomResourceGet>>, unknown> => useQuery(queryIds.classroomResourceGet(id), () => requests.classroomResourceGet(id), options),
        useDocumentResourceGetByLesson: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.documentResourceGetByLesson>>, unknown, Awaited<ReturnType<typeof requests.documentResourceGetByLesson>>, ReturnType<(typeof queryIds)["documentResourceGetByLesson"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.documentResourceGetByLesson>>, unknown> => useQuery(queryIds.documentResourceGetByLesson(id), () => requests.documentResourceGetByLesson(id), options),
        useDocumentResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.documentResourceGet>>, unknown, Awaited<ReturnType<typeof requests.documentResourceGet>>, ReturnType<(typeof queryIds)["documentResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.documentResourceGet>>, unknown> => useQuery(queryIds.documentResourceGet(id), () => requests.documentResourceGet(id), options),
        useExerciseAnswerResourceList: (q: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.exerciseAnswerResourceList>>, unknown, Awaited<ReturnType<typeof requests.exerciseAnswerResourceList>>, ReturnType<(typeof queryIds)["exerciseAnswerResourceList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.exerciseAnswerResourceList>>, unknown> => useQuery(queryIds.exerciseAnswerResourceList(q), () => requests.exerciseAnswerResourceList(q), options),
        useExerciseResourceList: (lesson_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.exerciseResourceList>>, unknown, Awaited<ReturnType<typeof requests.exerciseResourceList>>, ReturnType<(typeof queryIds)["exerciseResourceList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.exerciseResourceList>>, unknown> => useQuery(queryIds.exerciseResourceList(lesson_id), () => requests.exerciseResourceList(lesson_id), options),
        useExerciseQuestionResourceList: (exercise_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.exerciseQuestionResourceList>>, unknown, Awaited<ReturnType<typeof requests.exerciseQuestionResourceList>>, ReturnType<(typeof queryIds)["exerciseQuestionResourceList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.exerciseQuestionResourceList>>, unknown> => useQuery(queryIds.exerciseQuestionResourceList(exercise_id), () => requests.exerciseQuestionResourceList(exercise_id), options),
        useExerciseResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.exerciseResourceGet>>, unknown, Awaited<ReturnType<typeof requests.exerciseResourceGet>>, ReturnType<(typeof queryIds)["exerciseResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.exerciseResourceGet>>, unknown> => useQuery(queryIds.exerciseResourceGet(id), () => requests.exerciseResourceGet(id), options),
        useFilesResourceList: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.filesResourceList>>, unknown, Awaited<ReturnType<typeof requests.filesResourceList>>, ReturnType<(typeof queryIds)["filesResourceList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.filesResourceList>>, unknown> => useQuery(queryIds.filesResourceList(), () => requests.filesResourceList(), options),
        useFilesResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.filesResourceGet>>, unknown, Awaited<ReturnType<typeof requests.filesResourceGet>>, ReturnType<(typeof queryIds)["filesResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.filesResourceGet>>, unknown> => useQuery(queryIds.filesResourceGet(id), () => requests.filesResourceGet(id), options),
        useAssessmentAnswerResponseGetResponseByAnswer: (assessment_answer: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentAnswerResponseGetResponseByAnswer>>, unknown, Awaited<ReturnType<typeof requests.assessmentAnswerResponseGetResponseByAnswer>>, ReturnType<(typeof queryIds)["assessmentAnswerResponseGetResponseByAnswer"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentAnswerResponseGetResponseByAnswer>>, unknown> => useQuery(queryIds.assessmentAnswerResponseGetResponseByAnswer(assessment_answer), () => requests.assessmentAnswerResponseGetResponseByAnswer(assessment_answer), options),
        useAssessmentGradingResourceGetByAssessment: (assessment_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentGradingResourceGetByAssessment>>, unknown, Awaited<ReturnType<typeof requests.assessmentGradingResourceGetByAssessment>>, ReturnType<(typeof queryIds)["assessmentGradingResourceGetByAssessment"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentGradingResourceGetByAssessment>>, unknown> => useQuery(queryIds.assessmentGradingResourceGetByAssessment(assessment_id), () => requests.assessmentGradingResourceGetByAssessment(assessment_id), options),
        useAssessmentGradingResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentGradingResourceGet>>, unknown, Awaited<ReturnType<typeof requests.assessmentGradingResourceGet>>, ReturnType<(typeof queryIds)["assessmentGradingResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentGradingResourceGet>>, unknown> => useQuery(queryIds.assessmentGradingResourceGet(id), () => requests.assessmentGradingResourceGet(id), options),
        useExerciseGradingResourceGetByExercise: (exercise_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.exerciseGradingResourceGetByExercise>>, unknown, Awaited<ReturnType<typeof requests.exerciseGradingResourceGetByExercise>>, ReturnType<(typeof queryIds)["exerciseGradingResourceGetByExercise"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.exerciseGradingResourceGetByExercise>>, unknown> => useQuery(queryIds.exerciseGradingResourceGetByExercise(exercise_id), () => requests.exerciseGradingResourceGetByExercise(exercise_id), options),
        useExerciseGradingResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.exerciseGradingResourceGet>>, unknown, Awaited<ReturnType<typeof requests.exerciseGradingResourceGet>>, ReturnType<(typeof queryIds)["exerciseGradingResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.exerciseGradingResourceGet>>, unknown> => useQuery(queryIds.exerciseGradingResourceGet(id), () => requests.exerciseGradingResourceGet(id), options),
        useLessonsResourceGetLessonsByTopic: (topic_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.lessonsResourceGetLessonsByTopic>>, unknown, Awaited<ReturnType<typeof requests.lessonsResourceGetLessonsByTopic>>, ReturnType<(typeof queryIds)["lessonsResourceGetLessonsByTopic"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.lessonsResourceGetLessonsByTopic>>, unknown> => useQuery(queryIds.lessonsResourceGetLessonsByTopic(topic_id), () => requests.lessonsResourceGetLessonsByTopic(topic_id), options),
        useLessonsResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.lessonsResourceGet>>, unknown, Awaited<ReturnType<typeof requests.lessonsResourceGet>>, ReturnType<(typeof queryIds)["lessonsResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.lessonsResourceGet>>, unknown> => useQuery(queryIds.lessonsResourceGet(id), () => requests.lessonsResourceGet(id), options),
        useMediaResourceGetByPlaylist: (playlist_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.mediaResourceGetByPlaylist>>, unknown, Awaited<ReturnType<typeof requests.mediaResourceGetByPlaylist>>, ReturnType<(typeof queryIds)["mediaResourceGetByPlaylist"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.mediaResourceGetByPlaylist>>, unknown> => useQuery(queryIds.mediaResourceGetByPlaylist(playlist_id), () => requests.mediaResourceGetByPlaylist(playlist_id), options),
        useMediaResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.mediaResourceGet>>, unknown, Awaited<ReturnType<typeof requests.mediaResourceGet>>, ReturnType<(typeof queryIds)["mediaResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.mediaResourceGet>>, unknown> => useQuery(queryIds.mediaResourceGet(id), () => requests.mediaResourceGet(id), options),
        useNotesResourceGetNotesByLesson: (lesson_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.notesResourceGetNotesByLesson>>, unknown, Awaited<ReturnType<typeof requests.notesResourceGetNotesByLesson>>, ReturnType<(typeof queryIds)["notesResourceGetNotesByLesson"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.notesResourceGetNotesByLesson>>, unknown> => useQuery(queryIds.notesResourceGetNotesByLesson(lesson_id), () => requests.notesResourceGetNotesByLesson(lesson_id), options),
        useNotesResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.notesResourceGet>>, unknown, Awaited<ReturnType<typeof requests.notesResourceGet>>, ReturnType<(typeof queryIds)["notesResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.notesResourceGet>>, unknown> => useQuery(queryIds.notesResourceGet(id), () => requests.notesResourceGet(id), options),
        usePlanGroupResourceAll: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.planGroupResourceAll>>, unknown, Awaited<ReturnType<typeof requests.planGroupResourceAll>>, ReturnType<(typeof queryIds)["planGroupResourceAll"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.planGroupResourceAll>>, unknown> => useQuery(queryIds.planGroupResourceAll(), () => requests.planGroupResourceAll(), options),
        usePlanGroupResourceGetActive: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.planGroupResourceGetActive>>, unknown, Awaited<ReturnType<typeof requests.planGroupResourceGetActive>>, ReturnType<(typeof queryIds)["planGroupResourceGetActive"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.planGroupResourceGetActive>>, unknown> => useQuery(queryIds.planGroupResourceGetActive(), () => requests.planGroupResourceGetActive(), options),
        usePlanGroupResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.planGroupResourceGet>>, unknown, Awaited<ReturnType<typeof requests.planGroupResourceGet>>, ReturnType<(typeof queryIds)["planGroupResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.planGroupResourceGet>>, unknown> => useQuery(queryIds.planGroupResourceGet(id), () => requests.planGroupResourceGet(id), options),
        usePlaylistResourceGetPlaylistsByLesson: (lesson_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.playlistResourceGetPlaylistsByLesson>>, unknown, Awaited<ReturnType<typeof requests.playlistResourceGetPlaylistsByLesson>>, ReturnType<(typeof queryIds)["playlistResourceGetPlaylistsByLesson"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.playlistResourceGetPlaylistsByLesson>>, unknown> => useQuery(queryIds.playlistResourceGetPlaylistsByLesson(lesson_id), () => requests.playlistResourceGetPlaylistsByLesson(lesson_id), options),
        usePlaylistResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.playlistResourceGet>>, unknown, Awaited<ReturnType<typeof requests.playlistResourceGet>>, ReturnType<(typeof queryIds)["playlistResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.playlistResourceGet>>, unknown> => useQuery(queryIds.playlistResourceGet(id), () => requests.playlistResourceGet(id), options),
        useStatsResourceGetStats: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.statsResourceGetStats>>, unknown, Awaited<ReturnType<typeof requests.statsResourceGetStats>>, ReturnType<(typeof queryIds)["statsResourceGetStats"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.statsResourceGetStats>>, unknown> => useQuery(queryIds.statsResourceGetStats(), () => requests.statsResourceGetStats(), options),
        useSubjectsResourceListByClassroom: (classroom_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.subjectsResourceListByClassroom>>, unknown, Awaited<ReturnType<typeof requests.subjectsResourceListByClassroom>>, ReturnType<(typeof queryIds)["subjectsResourceListByClassroom"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.subjectsResourceListByClassroom>>, unknown> => useQuery(queryIds.subjectsResourceListByClassroom(classroom_id), () => requests.subjectsResourceListByClassroom(classroom_id), options),
        useSubjectsResourceGetByStudentLevel: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.subjectsResourceGetByStudentLevel>>, unknown, Awaited<ReturnType<typeof requests.subjectsResourceGetByStudentLevel>>, ReturnType<(typeof queryIds)["subjectsResourceGetByStudentLevel"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.subjectsResourceGetByStudentLevel>>, unknown> => useQuery(queryIds.subjectsResourceGetByStudentLevel(), () => requests.subjectsResourceGetByStudentLevel(), options),
        useSubjectsResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.subjectsResourceGet>>, unknown, Awaited<ReturnType<typeof requests.subjectsResourceGet>>, ReturnType<(typeof queryIds)["subjectsResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.subjectsResourceGet>>, unknown> => useQuery(queryIds.subjectsResourceGet(id), () => requests.subjectsResourceGet(id), options),
        useSubjectsResourceGetByTeacher: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.subjectsResourceGetByTeacher>>, unknown, Awaited<ReturnType<typeof requests.subjectsResourceGetByTeacher>>, ReturnType<(typeof queryIds)["subjectsResourceGetByTeacher"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.subjectsResourceGetByTeacher>>, unknown> => useQuery(queryIds.subjectsResourceGetByTeacher(), () => requests.subjectsResourceGetByTeacher(), options),
        useSubscriptionResourceGetSubByClassroom: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.subscriptionResourceGetSubByClassroom>>, unknown, Awaited<ReturnType<typeof requests.subscriptionResourceGetSubByClassroom>>, ReturnType<(typeof queryIds)["subscriptionResourceGetSubByClassroom"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.subscriptionResourceGetSubByClassroom>>, unknown> => useQuery(queryIds.subscriptionResourceGetSubByClassroom(id), () => requests.subscriptionResourceGetSubByClassroom(id), options),
        useSubscriptionResourceGetByPlanGroup: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.subscriptionResourceGetByPlanGroup>>, unknown, Awaited<ReturnType<typeof requests.subscriptionResourceGetByPlanGroup>>, ReturnType<(typeof queryIds)["subscriptionResourceGetByPlanGroup"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.subscriptionResourceGetByPlanGroup>>, unknown> => useQuery(queryIds.subscriptionResourceGetByPlanGroup(id), () => requests.subscriptionResourceGetByPlanGroup(id), options),
        useSubscriptionResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.subscriptionResourceGet>>, unknown, Awaited<ReturnType<typeof requests.subscriptionResourceGet>>, ReturnType<(typeof queryIds)["subscriptionResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.subscriptionResourceGet>>, unknown> => useQuery(queryIds.subscriptionResourceGet(id), () => requests.subscriptionResourceGet(id), options),
        useSubscriptionTransactionResourceAll: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.subscriptionTransactionResourceAll>>, unknown, Awaited<ReturnType<typeof requests.subscriptionTransactionResourceAll>>, ReturnType<(typeof queryIds)["subscriptionTransactionResourceAll"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.subscriptionTransactionResourceAll>>, unknown> => useQuery(queryIds.subscriptionTransactionResourceAll(), () => requests.subscriptionTransactionResourceAll(), options),
        useTaskResourceListAll: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.taskResourceListAll>>, unknown, Awaited<ReturnType<typeof requests.taskResourceListAll>>, ReturnType<(typeof queryIds)["taskResourceListAll"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.taskResourceListAll>>, unknown> => useQuery(queryIds.taskResourceListAll(), () => requests.taskResourceListAll(), options),
        useTopicsResourceGetTopicsBySubject: (subject_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.topicsResourceGetTopicsBySubject>>, unknown, Awaited<ReturnType<typeof requests.topicsResourceGetTopicsBySubject>>, ReturnType<(typeof queryIds)["topicsResourceGetTopicsBySubject"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.topicsResourceGetTopicsBySubject>>, unknown> => useQuery(queryIds.topicsResourceGetTopicsBySubject(subject_id), () => requests.topicsResourceGetTopicsBySubject(subject_id), options),
        useTopicsResourceGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.topicsResourceGet>>, unknown, Awaited<ReturnType<typeof requests.topicsResourceGet>>, ReturnType<(typeof queryIds)["topicsResourceGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.topicsResourceGet>>, unknown> => useQuery(queryIds.topicsResourceGet(id), () => requests.topicsResourceGet(id), options),
        useUserResourceGetStudent: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.userResourceGetStudent>>, unknown, Awaited<ReturnType<typeof requests.userResourceGetStudent>>, ReturnType<(typeof queryIds)["userResourceGetStudent"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.userResourceGetStudent>>, unknown> => useQuery(queryIds.userResourceGetStudent(), () => requests.userResourceGetStudent(), options),
        useUserResourceGetTeacher: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.userResourceGetTeacher>>, unknown, Awaited<ReturnType<typeof requests.userResourceGetTeacher>>, ReturnType<(typeof queryIds)["userResourceGetTeacher"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.userResourceGetTeacher>>, unknown> => useQuery(queryIds.userResourceGetTeacher(), () => requests.userResourceGetTeacher(), options),
        useUtilsGetCategory: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.utilsGetCategory>>, unknown, Awaited<ReturnType<typeof requests.utilsGetCategory>>, ReturnType<(typeof queryIds)["utilsGetCategory"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.utilsGetCategory>>, unknown> => useQuery(queryIds.utilsGetCategory(), () => requests.utilsGetCategory(), options),
        useUtilsGetGrades: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.utilsGetGrades>>, unknown, Awaited<ReturnType<typeof requests.utilsGetGrades>>, ReturnType<(typeof queryIds)["utilsGetGrades"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.utilsGetGrades>>, unknown> => useQuery(queryIds.utilsGetGrades(), () => requests.utilsGetGrades(), options),
        useUtilsGetPlan: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.utilsGetPlan>>, unknown, Awaited<ReturnType<typeof requests.utilsGetPlan>>, ReturnType<(typeof queryIds)["utilsGetPlan"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.utilsGetPlan>>, unknown> => useQuery(queryIds.utilsGetPlan(), () => requests.utilsGetPlan(), options),
        useUtilsGetPlaylist: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.utilsGetPlaylist>>, unknown, Awaited<ReturnType<typeof requests.utilsGetPlaylist>>, ReturnType<(typeof queryIds)["utilsGetPlaylist"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.utilsGetPlaylist>>, unknown> => useQuery(queryIds.utilsGetPlaylist(), () => requests.utilsGetPlaylist(), options),
        useUtilsGetRecurrenceUnit: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.utilsGetRecurrenceUnit>>, unknown, Awaited<ReturnType<typeof requests.utilsGetRecurrenceUnit>>, ReturnType<(typeof queryIds)["utilsGetRecurrenceUnit"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.utilsGetRecurrenceUnit>>, unknown> => useQuery(queryIds.utilsGetRecurrenceUnit(), () => requests.utilsGetRecurrenceUnit(), options),
        useUtilsGetSubjects: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.utilsGetSubjects>>, unknown, Awaited<ReturnType<typeof requests.utilsGetSubjects>>, ReturnType<(typeof queryIds)["utilsGetSubjects"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.utilsGetSubjects>>, unknown> => useQuery(queryIds.utilsGetSubjects(), () => requests.utilsGetSubjects(), options)
    } as const;
}
type MutationConfigs = {
    useAssessmentResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResourceDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentResourceComplete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentResourceComplete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentResourceComplete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentQuestionResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentQuestionResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentQuestionResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentQuestionResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentQuestionResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentQuestionResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentQuestionResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentQuestionResourceDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentResourceStart?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentResourceStart"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentResourceStart"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAuthenticationResourceLogin?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["authenticationResourceLogin"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["authenticationResourceLogin"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAuthenticationResourceRegister?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["authenticationResourceRegister"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["authenticationResourceRegister"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useClassroomResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["classroomResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["classroomResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useClassroomResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["classroomResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["classroomResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useClassroomResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["classroomResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["classroomResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useDocumentResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["documentResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["documentResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseAnswerResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseAnswerResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerResourceDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseResourceComplete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseResourceComplete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseResourceComplete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseQuestionResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseQuestionResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseQuestionResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseQuestionResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseQuestionResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseQuestionResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseQuestionResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseQuestionResourceDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseResourceStart?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseResourceStart"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseResourceStart"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useFilesResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["filesResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["filesResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useFilesResourceComplete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["filesResourceComplete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResponseCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResponseCreateLong?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreateLong"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreateLong"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerResponseCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerResponseCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseAnswerResponseCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentGradingResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingResourceCompleteMarking?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingResourceCompleteMarking"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingResourceMark?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingResourceMark"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentGradingResourceMark"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingResourceMarkLong?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingResourceMarkLong"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentGradingResourceMarkLong"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseGradingResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseGradingResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseGradingResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseGradingResourceMark?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseGradingResourceMark"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseGradingResourceMark"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useLessonsResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["lessonsResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["lessonsResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useLessonsResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["lessonsResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["lessonsResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useLessonsResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["lessonsResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["lessonsResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useMediaResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["mediaResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["mediaResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useMediaResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["mediaResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["mediaResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useMediaResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["mediaResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["mediaResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useNotesResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["notesResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["notesResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useNotesResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["notesResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["notesResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useNotesResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["notesResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["notesResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useWebhookResourcePost?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["webhookResourcePost"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["webhookResourcePost"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlanGroupResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["planGroupResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["planGroupResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlaylistResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["playlistResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["playlistResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlaylistResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["playlistResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["playlistResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlaylistResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["playlistResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["playlistResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsResourceCreateClassroomSubject?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsResourceCreateClassroomSubject"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsResourceCreateClassroomSubject"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsResourceCreateSubject?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsResourceCreateSubject"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsResourceCreateSubject"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceCheckClassroomSub?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceCheckClassroomSub"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceClassroomSub?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceClassroomSub"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionResourceClassroomSub"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceUserSub?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceUserSub"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionResourceUserSub"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionTransactionResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionTransactionResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionTransactionResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionTransactionResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionTransactionResourceDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useTopicsResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["topicsResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["topicsResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useTopicsResourceDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["topicsResourceDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["topicsResourceDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useTopicsResourceUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["topicsResourceUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["topicsResourceUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useUserResourceF?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["userResourceF"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useUserResourceCreateStudent?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["userResourceCreateStudent"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["userResourceCreateStudent"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useUserResourceCreateTeacher?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["userResourceCreateTeacher"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
};
function makeMutations(requests: ReturnType<typeof makeRequests>, config?: Config["mutations"]) {
    return {
        useAssessmentResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentResourceCreate>>, unknown, Parameters<typeof requests.assessmentResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentResourceCreate>>, unknown, Parameters<typeof requests.assessmentResourceCreate>[0]>(payload => requests.assessmentResourceCreate(payload), config?.useAssessmentResourceCreate, options),
        useAssessmentResourceDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentResourceDelete>>, unknown, Parameters<typeof requests.assessmentResourceDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentResourceDelete>>, unknown, Parameters<typeof requests.assessmentResourceDelete>[0]>(payload => requests.assessmentResourceDelete(payload), config?.useAssessmentResourceDelete, options),
        useAssessmentAnswerResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentAnswerResourceCreate>>, unknown, Parameters<typeof requests.assessmentAnswerResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentAnswerResourceCreate>>, unknown, Parameters<typeof requests.assessmentAnswerResourceCreate>[0]>(payload => requests.assessmentAnswerResourceCreate(payload), config?.useAssessmentAnswerResourceCreate, options),
        useAssessmentAnswerResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentAnswerResourceUpdate>>, unknown, Parameters<typeof requests.assessmentAnswerResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentAnswerResourceUpdate>>, unknown, Parameters<typeof requests.assessmentAnswerResourceUpdate>[0]>(payload => requests.assessmentAnswerResourceUpdate(payload, id), config?.useAssessmentAnswerResourceUpdate, options),
        useAssessmentAnswerResourceDelete: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentAnswerResourceDelete>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentAnswerResourceDelete>>, unknown, unknown>(() => requests.assessmentAnswerResourceDelete(id), config?.useAssessmentAnswerResourceDelete, options),
        useAssessmentResourceComplete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentResourceComplete>>, unknown, Parameters<typeof requests.assessmentResourceComplete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentResourceComplete>>, unknown, Parameters<typeof requests.assessmentResourceComplete>[0]>(payload => requests.assessmentResourceComplete(payload), config?.useAssessmentResourceComplete, options),
        useAssessmentQuestionResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentQuestionResourceCreate>>, unknown, Parameters<typeof requests.assessmentQuestionResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentQuestionResourceCreate>>, unknown, Parameters<typeof requests.assessmentQuestionResourceCreate>[0]>(payload => requests.assessmentQuestionResourceCreate(payload), config?.useAssessmentQuestionResourceCreate, options),
        useAssessmentQuestionResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentQuestionResourceUpdate>>, unknown, Parameters<typeof requests.assessmentQuestionResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentQuestionResourceUpdate>>, unknown, Parameters<typeof requests.assessmentQuestionResourceUpdate>[0]>(payload => requests.assessmentQuestionResourceUpdate(payload, id), config?.useAssessmentQuestionResourceUpdate, options),
        useAssessmentQuestionResourceDelete: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentQuestionResourceDelete>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentQuestionResourceDelete>>, unknown, unknown>(() => requests.assessmentQuestionResourceDelete(id), config?.useAssessmentQuestionResourceDelete, options),
        useAssessmentResourceStart: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentResourceStart>>, unknown, Parameters<typeof requests.assessmentResourceStart>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentResourceStart>>, unknown, Parameters<typeof requests.assessmentResourceStart>[0]>(payload => requests.assessmentResourceStart(payload), config?.useAssessmentResourceStart, options),
        useAssessmentResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentResourceUpdate>>, unknown, Parameters<typeof requests.assessmentResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentResourceUpdate>>, unknown, Parameters<typeof requests.assessmentResourceUpdate>[0]>(payload => requests.assessmentResourceUpdate(payload, id), config?.useAssessmentResourceUpdate, options),
        useAuthenticationResourceLogin: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.authenticationResourceLogin>>, unknown, Parameters<typeof requests.authenticationResourceLogin>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.authenticationResourceLogin>>, unknown, Parameters<typeof requests.authenticationResourceLogin>[0]>(payload => requests.authenticationResourceLogin(payload), config?.useAuthenticationResourceLogin, options),
        useAuthenticationResourceRegister: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.authenticationResourceRegister>>, unknown, Parameters<typeof requests.authenticationResourceRegister>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.authenticationResourceRegister>>, unknown, Parameters<typeof requests.authenticationResourceRegister>[0]>(payload => requests.authenticationResourceRegister(payload), config?.useAuthenticationResourceRegister, options),
        useClassroomResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.classroomResourceCreate>>, unknown, Parameters<typeof requests.classroomResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.classroomResourceCreate>>, unknown, Parameters<typeof requests.classroomResourceCreate>[0]>(payload => requests.classroomResourceCreate(payload), config?.useClassroomResourceCreate, options),
        useClassroomResourceDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.classroomResourceDelete>>, unknown, Parameters<typeof requests.classroomResourceDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.classroomResourceDelete>>, unknown, Parameters<typeof requests.classroomResourceDelete>[0]>(payload => requests.classroomResourceDelete(payload), config?.useClassroomResourceDelete, options),
        useClassroomResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.classroomResourceUpdate>>, unknown, Parameters<typeof requests.classroomResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.classroomResourceUpdate>>, unknown, Parameters<typeof requests.classroomResourceUpdate>[0]>(payload => requests.classroomResourceUpdate(payload, id), config?.useClassroomResourceUpdate, options),
        useDocumentResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.documentResourceCreate>>, unknown, Parameters<typeof requests.documentResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.documentResourceCreate>>, unknown, Parameters<typeof requests.documentResourceCreate>[0]>(payload => requests.documentResourceCreate(payload), config?.useDocumentResourceCreate, options),
        useExerciseResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseResourceCreate>>, unknown, Parameters<typeof requests.exerciseResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseResourceCreate>>, unknown, Parameters<typeof requests.exerciseResourceCreate>[0]>(payload => requests.exerciseResourceCreate(payload), config?.useExerciseResourceCreate, options),
        useExerciseResourceDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseResourceDelete>>, unknown, Parameters<typeof requests.exerciseResourceDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseResourceDelete>>, unknown, Parameters<typeof requests.exerciseResourceDelete>[0]>(payload => requests.exerciseResourceDelete(payload), config?.useExerciseResourceDelete, options),
        useExerciseAnswerResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseAnswerResourceCreate>>, unknown, Parameters<typeof requests.exerciseAnswerResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseAnswerResourceCreate>>, unknown, Parameters<typeof requests.exerciseAnswerResourceCreate>[0]>(payload => requests.exerciseAnswerResourceCreate(payload), config?.useExerciseAnswerResourceCreate, options),
        useExerciseAnswerResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseAnswerResourceUpdate>>, unknown, Parameters<typeof requests.exerciseAnswerResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseAnswerResourceUpdate>>, unknown, Parameters<typeof requests.exerciseAnswerResourceUpdate>[0]>(payload => requests.exerciseAnswerResourceUpdate(payload, id), config?.useExerciseAnswerResourceUpdate, options),
        useExerciseAnswerResourceDelete: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseAnswerResourceDelete>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseAnswerResourceDelete>>, unknown, unknown>(() => requests.exerciseAnswerResourceDelete(id), config?.useExerciseAnswerResourceDelete, options),
        useExerciseResourceComplete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseResourceComplete>>, unknown, Parameters<typeof requests.exerciseResourceComplete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseResourceComplete>>, unknown, Parameters<typeof requests.exerciseResourceComplete>[0]>(payload => requests.exerciseResourceComplete(payload), config?.useExerciseResourceComplete, options),
        useExerciseQuestionResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseQuestionResourceCreate>>, unknown, Parameters<typeof requests.exerciseQuestionResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseQuestionResourceCreate>>, unknown, Parameters<typeof requests.exerciseQuestionResourceCreate>[0]>(payload => requests.exerciseQuestionResourceCreate(payload), config?.useExerciseQuestionResourceCreate, options),
        useExerciseQuestionResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseQuestionResourceUpdate>>, unknown, Parameters<typeof requests.exerciseQuestionResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseQuestionResourceUpdate>>, unknown, Parameters<typeof requests.exerciseQuestionResourceUpdate>[0]>(payload => requests.exerciseQuestionResourceUpdate(payload, id), config?.useExerciseQuestionResourceUpdate, options),
        useExerciseQuestionResourceDelete: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseQuestionResourceDelete>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseQuestionResourceDelete>>, unknown, unknown>(() => requests.exerciseQuestionResourceDelete(id), config?.useExerciseQuestionResourceDelete, options),
        useExerciseResourceStart: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseResourceStart>>, unknown, Parameters<typeof requests.exerciseResourceStart>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseResourceStart>>, unknown, Parameters<typeof requests.exerciseResourceStart>[0]>(payload => requests.exerciseResourceStart(payload), config?.useExerciseResourceStart, options),
        useExerciseResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseResourceUpdate>>, unknown, Parameters<typeof requests.exerciseResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseResourceUpdate>>, unknown, Parameters<typeof requests.exerciseResourceUpdate>[0]>(payload => requests.exerciseResourceUpdate(payload, id), config?.useExerciseResourceUpdate, options),
        useFilesResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.filesResourceCreate>>, unknown, Parameters<typeof requests.filesResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.filesResourceCreate>>, unknown, Parameters<typeof requests.filesResourceCreate>[0]>(payload => requests.filesResourceCreate(payload), config?.useFilesResourceCreate, options),
        useFilesResourceComplete: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.filesResourceComplete>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.filesResourceComplete>>, unknown, unknown>(() => requests.filesResourceComplete(id), config?.useFilesResourceComplete, options),
        useAssessmentAnswerResponseCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentAnswerResponseCreate>>, unknown, Parameters<typeof requests.assessmentAnswerResponseCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentAnswerResponseCreate>>, unknown, Parameters<typeof requests.assessmentAnswerResponseCreate>[0]>(payload => requests.assessmentAnswerResponseCreate(payload), config?.useAssessmentAnswerResponseCreate, options),
        useAssessmentAnswerResponseCreateLong: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentAnswerResponseCreateLong>>, unknown, Parameters<typeof requests.assessmentAnswerResponseCreateLong>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentAnswerResponseCreateLong>>, unknown, Parameters<typeof requests.assessmentAnswerResponseCreateLong>[0]>(payload => requests.assessmentAnswerResponseCreateLong(payload), config?.useAssessmentAnswerResponseCreateLong, options),
        useExerciseAnswerResponseCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseAnswerResponseCreate>>, unknown, Parameters<typeof requests.exerciseAnswerResponseCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseAnswerResponseCreate>>, unknown, Parameters<typeof requests.exerciseAnswerResponseCreate>[0]>(payload => requests.exerciseAnswerResponseCreate(payload), config?.useExerciseAnswerResponseCreate, options),
        useAssessmentGradingResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentGradingResourceCreate>>, unknown, Parameters<typeof requests.assessmentGradingResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentGradingResourceCreate>>, unknown, Parameters<typeof requests.assessmentGradingResourceCreate>[0]>(payload => requests.assessmentGradingResourceCreate(payload), config?.useAssessmentGradingResourceCreate, options),
        useAssessmentGradingResourceCompleteMarking: (report_id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentGradingResourceCompleteMarking>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentGradingResourceCompleteMarking>>, unknown, unknown>(() => requests.assessmentGradingResourceCompleteMarking(report_id), config?.useAssessmentGradingResourceCompleteMarking, options),
        useAssessmentGradingResourceMark: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentGradingResourceMark>>, unknown, Parameters<typeof requests.assessmentGradingResourceMark>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentGradingResourceMark>>, unknown, Parameters<typeof requests.assessmentGradingResourceMark>[0]>(payload => requests.assessmentGradingResourceMark(payload), config?.useAssessmentGradingResourceMark, options),
        useAssessmentGradingResourceMarkLong: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentGradingResourceMarkLong>>, unknown, Parameters<typeof requests.assessmentGradingResourceMarkLong>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentGradingResourceMarkLong>>, unknown, Parameters<typeof requests.assessmentGradingResourceMarkLong>[0]>(payload => requests.assessmentGradingResourceMarkLong(payload), config?.useAssessmentGradingResourceMarkLong, options),
        useExerciseGradingResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseGradingResourceCreate>>, unknown, Parameters<typeof requests.exerciseGradingResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseGradingResourceCreate>>, unknown, Parameters<typeof requests.exerciseGradingResourceCreate>[0]>(payload => requests.exerciseGradingResourceCreate(payload), config?.useExerciseGradingResourceCreate, options),
        useExerciseGradingResourceMark: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseGradingResourceMark>>, unknown, Parameters<typeof requests.exerciseGradingResourceMark>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseGradingResourceMark>>, unknown, Parameters<typeof requests.exerciseGradingResourceMark>[0]>(payload => requests.exerciseGradingResourceMark(payload), config?.useExerciseGradingResourceMark, options),
        useLessonsResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.lessonsResourceCreate>>, unknown, Parameters<typeof requests.lessonsResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.lessonsResourceCreate>>, unknown, Parameters<typeof requests.lessonsResourceCreate>[0]>(payload => requests.lessonsResourceCreate(payload), config?.useLessonsResourceCreate, options),
        useLessonsResourceDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.lessonsResourceDelete>>, unknown, Parameters<typeof requests.lessonsResourceDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.lessonsResourceDelete>>, unknown, Parameters<typeof requests.lessonsResourceDelete>[0]>(payload => requests.lessonsResourceDelete(payload), config?.useLessonsResourceDelete, options),
        useLessonsResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.lessonsResourceUpdate>>, unknown, Parameters<typeof requests.lessonsResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.lessonsResourceUpdate>>, unknown, Parameters<typeof requests.lessonsResourceUpdate>[0]>(payload => requests.lessonsResourceUpdate(payload, id), config?.useLessonsResourceUpdate, options),
        useMediaResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.mediaResourceCreate>>, unknown, Parameters<typeof requests.mediaResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.mediaResourceCreate>>, unknown, Parameters<typeof requests.mediaResourceCreate>[0]>(payload => requests.mediaResourceCreate(payload), config?.useMediaResourceCreate, options),
        useMediaResourceDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.mediaResourceDelete>>, unknown, Parameters<typeof requests.mediaResourceDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.mediaResourceDelete>>, unknown, Parameters<typeof requests.mediaResourceDelete>[0]>(payload => requests.mediaResourceDelete(payload), config?.useMediaResourceDelete, options),
        useMediaResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.mediaResourceUpdate>>, unknown, Parameters<typeof requests.mediaResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.mediaResourceUpdate>>, unknown, Parameters<typeof requests.mediaResourceUpdate>[0]>(payload => requests.mediaResourceUpdate(payload, id), config?.useMediaResourceUpdate, options),
        useNotesResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.notesResourceCreate>>, unknown, Parameters<typeof requests.notesResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.notesResourceCreate>>, unknown, Parameters<typeof requests.notesResourceCreate>[0]>(payload => requests.notesResourceCreate(payload), config?.useNotesResourceCreate, options),
        useNotesResourceDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.notesResourceDelete>>, unknown, Parameters<typeof requests.notesResourceDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.notesResourceDelete>>, unknown, Parameters<typeof requests.notesResourceDelete>[0]>(payload => requests.notesResourceDelete(payload), config?.useNotesResourceDelete, options),
        useNotesResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.notesResourceUpdate>>, unknown, Parameters<typeof requests.notesResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.notesResourceUpdate>>, unknown, Parameters<typeof requests.notesResourceUpdate>[0]>(payload => requests.notesResourceUpdate(payload, id), config?.useNotesResourceUpdate, options),
        useWebhookResourcePost: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.webhookResourcePost>>, unknown, Parameters<typeof requests.webhookResourcePost>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.webhookResourcePost>>, unknown, Parameters<typeof requests.webhookResourcePost>[0]>(payload => requests.webhookResourcePost(payload), config?.useWebhookResourcePost, options),
        usePlanGroupResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.planGroupResourceCreate>>, unknown, Parameters<typeof requests.planGroupResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.planGroupResourceCreate>>, unknown, Parameters<typeof requests.planGroupResourceCreate>[0]>(payload => requests.planGroupResourceCreate(payload), config?.usePlanGroupResourceCreate, options),
        usePlaylistResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.playlistResourceCreate>>, unknown, Parameters<typeof requests.playlistResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.playlistResourceCreate>>, unknown, Parameters<typeof requests.playlistResourceCreate>[0]>(payload => requests.playlistResourceCreate(payload), config?.usePlaylistResourceCreate, options),
        usePlaylistResourceDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.playlistResourceDelete>>, unknown, Parameters<typeof requests.playlistResourceDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.playlistResourceDelete>>, unknown, Parameters<typeof requests.playlistResourceDelete>[0]>(payload => requests.playlistResourceDelete(payload), config?.usePlaylistResourceDelete, options),
        usePlaylistResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.playlistResourceUpdate>>, unknown, Parameters<typeof requests.playlistResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.playlistResourceUpdate>>, unknown, Parameters<typeof requests.playlistResourceUpdate>[0]>(payload => requests.playlistResourceUpdate(payload, id), config?.usePlaylistResourceUpdate, options),
        useSubjectsResourceDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subjectsResourceDelete>>, unknown, Parameters<typeof requests.subjectsResourceDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subjectsResourceDelete>>, unknown, Parameters<typeof requests.subjectsResourceDelete>[0]>(payload => requests.subjectsResourceDelete(payload), config?.useSubjectsResourceDelete, options),
        useSubjectsResourceCreateClassroomSubject: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subjectsResourceCreateClassroomSubject>>, unknown, Parameters<typeof requests.subjectsResourceCreateClassroomSubject>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subjectsResourceCreateClassroomSubject>>, unknown, Parameters<typeof requests.subjectsResourceCreateClassroomSubject>[0]>(payload => requests.subjectsResourceCreateClassroomSubject(payload), config?.useSubjectsResourceCreateClassroomSubject, options),
        useSubjectsResourceCreateSubject: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subjectsResourceCreateSubject>>, unknown, Parameters<typeof requests.subjectsResourceCreateSubject>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subjectsResourceCreateSubject>>, unknown, Parameters<typeof requests.subjectsResourceCreateSubject>[0]>(payload => requests.subjectsResourceCreateSubject(payload), config?.useSubjectsResourceCreateSubject, options),
        useSubjectsResourceUpdate: (id: string, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subjectsResourceUpdate>>, unknown, Parameters<typeof requests.subjectsResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subjectsResourceUpdate>>, unknown, Parameters<typeof requests.subjectsResourceUpdate>[0]>(payload => requests.subjectsResourceUpdate(payload, id), config?.useSubjectsResourceUpdate, options),
        useSubscriptionResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subscriptionResourceCreate>>, unknown, Parameters<typeof requests.subscriptionResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subscriptionResourceCreate>>, unknown, Parameters<typeof requests.subscriptionResourceCreate>[0]>(payload => requests.subscriptionResourceCreate(payload), config?.useSubscriptionResourceCreate, options),
        useSubscriptionResourceCheckClassroomSub: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subscriptionResourceCheckClassroomSub>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subscriptionResourceCheckClassroomSub>>, unknown, unknown>(() => requests.subscriptionResourceCheckClassroomSub(id), config?.useSubscriptionResourceCheckClassroomSub, options),
        useSubscriptionResourceClassroomSub: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subscriptionResourceClassroomSub>>, unknown, Parameters<typeof requests.subscriptionResourceClassroomSub>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subscriptionResourceClassroomSub>>, unknown, Parameters<typeof requests.subscriptionResourceClassroomSub>[0]>(payload => requests.subscriptionResourceClassroomSub(payload), config?.useSubscriptionResourceClassroomSub, options),
        useSubscriptionResourceUserSub: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subscriptionResourceUserSub>>, unknown, Parameters<typeof requests.subscriptionResourceUserSub>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subscriptionResourceUserSub>>, unknown, Parameters<typeof requests.subscriptionResourceUserSub>[0]>(payload => requests.subscriptionResourceUserSub(payload), config?.useSubscriptionResourceUserSub, options),
        useSubscriptionResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subscriptionResourceUpdate>>, unknown, Parameters<typeof requests.subscriptionResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subscriptionResourceUpdate>>, unknown, Parameters<typeof requests.subscriptionResourceUpdate>[0]>(payload => requests.subscriptionResourceUpdate(payload, id), config?.useSubscriptionResourceUpdate, options),
        useSubscriptionTransactionResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subscriptionTransactionResourceCreate>>, unknown, Parameters<typeof requests.subscriptionTransactionResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subscriptionTransactionResourceCreate>>, unknown, Parameters<typeof requests.subscriptionTransactionResourceCreate>[0]>(payload => requests.subscriptionTransactionResourceCreate(payload), config?.useSubscriptionTransactionResourceCreate, options),
        useSubscriptionTransactionResourceDelete: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subscriptionTransactionResourceDelete>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subscriptionTransactionResourceDelete>>, unknown, unknown>(() => requests.subscriptionTransactionResourceDelete(id), config?.useSubscriptionTransactionResourceDelete, options),
        useTopicsResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.topicsResourceCreate>>, unknown, Parameters<typeof requests.topicsResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.topicsResourceCreate>>, unknown, Parameters<typeof requests.topicsResourceCreate>[0]>(payload => requests.topicsResourceCreate(payload), config?.useTopicsResourceCreate, options),
        useTopicsResourceDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.topicsResourceDelete>>, unknown, Parameters<typeof requests.topicsResourceDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.topicsResourceDelete>>, unknown, Parameters<typeof requests.topicsResourceDelete>[0]>(payload => requests.topicsResourceDelete(payload), config?.useTopicsResourceDelete, options),
        useTopicsResourceUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.topicsResourceUpdate>>, unknown, Parameters<typeof requests.topicsResourceUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.topicsResourceUpdate>>, unknown, Parameters<typeof requests.topicsResourceUpdate>[0]>(payload => requests.topicsResourceUpdate(payload, id), config?.useTopicsResourceUpdate, options),
        useUserResourceF: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.userResourceF>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.userResourceF>>, unknown, unknown>(() => requests.userResourceF(), config?.useUserResourceF, options),
        useUserResourceCreateStudent: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.userResourceCreateStudent>>, unknown, Parameters<typeof requests.userResourceCreateStudent>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.userResourceCreateStudent>>, unknown, Parameters<typeof requests.userResourceCreateStudent>[0]>(payload => requests.userResourceCreateStudent(payload), config?.useUserResourceCreateStudent, options),
        useUserResourceCreateTeacher: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.userResourceCreateTeacher>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.userResourceCreateTeacher>>, unknown, unknown>(() => requests.userResourceCreateTeacher(), config?.useUserResourceCreateTeacher, options)
    } as const;
}
